"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def create(
    hub,
    ctx,
    job_template_id: str,
    description: str,
    job_arn: str = None,
    document_source: str = None,
    document: str = None,
    presigned_url_config: Dict = None,
    job_executions_rollout_config: Dict = None,
    abort_config: Dict = None,
    timeout_config: Dict = None,
    tags: List = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Creates a job template.

    Args:
        job_template_id(str): A unique identifier for the job template. We recommend using a UUID. Alpha-numeric characters, "-", and "_" are valid for use here.
        job_arn(str, optional): The ARN of the job to use as the basis for the job template. Defaults to None.
        document_source(str, optional): An S3 link to the job document to use in the template. Required if you don't specify a value for document.  If the job document resides in an S3 bucket, you must use a placeholder link when specifying the document. The placeholder link is of the following form:  ${aws:iot:s3-presigned-url:https://s3.amazonaws.com/bucket/key}  where bucket is your bucket name and key is the object in the bucket to which you are linking. . Defaults to None.
        document(str, optional): The job document. Required if you don't specify a value for documentSource. Defaults to None.
        description(str): A description of the job document.
        presigned_url_config(Dict, optional): Configuration for pre-signed S3 URLs. Defaults to None.
        job_executions_rollout_config(Dict, optional): Allows you to create a staged rollout of a job. Defaults to None.
        abort_config(Dict, optional): The criteria that determine when and how a job abort takes place. Defaults to None.
        timeout_config(Dict, optional): Specifies the amount of time each device has to finish its execution of the job. A timer is started when the job execution status is set to IN_PROGRESS. If the job execution status is not set to another terminal state before the timer expires, it will be automatically set to TIMED_OUT. Defaults to None.
        tags(List, optional): Metadata that can be used to manage the job template. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.iot.job.template.create(
                ctx, job_template_id=value, description=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.iot.job.template.create job_template_id=value, description=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="iot",
        operation="create_job_template",
        op_kwargs={
            "jobTemplateId": job_template_id,
            "jobArn": job_arn,
            "documentSource": document_source,
            "document": document,
            "description": description,
            "presignedUrlConfig": presigned_url_config,
            "jobExecutionsRolloutConfig": job_executions_rollout_config,
            "abortConfig": abort_config,
            "timeoutConfig": timeout_config,
            "tags": tags,
        },
    )


async def delete(hub, ctx, job_template_id: str) -> None:
    r"""
    **Autogenerated function**

    Deletes the specified job template.

    Args:
        job_template_id(str): The unique identifier of the job template to delete.
    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.iot.job.template.delete(ctx, job_template_id=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.iot.job.template.delete job_template_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="iot",
        operation="delete_job_template",
        op_kwargs={"jobTemplateId": job_template_id},
    )


async def describe(hub, ctx, job_template_id: str) -> Dict:
    r"""
    **Autogenerated function**

    Returns information about a job template.

    Args:
        job_template_id(str): The unique identifier of the job template.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.iot.job.template.describe(ctx, job_template_id=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.iot.job.template.describe job_template_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="iot",
        operation="describe_job_template",
        op_kwargs={"jobTemplateId": job_template_id},
    )


async def list_all(hub, ctx, max_results: int = None, next_token: str = None) -> Dict:
    r"""
    **Autogenerated function**

    Returns a list of job templates.

    Args:
        max_results(int, optional): The maximum number of results to return in the list. Defaults to None.
        next_token(str, optional): The token to use to return the next set of results in the list. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.iot.job.template.list_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.iot.job.template.list_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="iot",
        operation="list_job_templates",
        op_kwargs={"maxResults": max_results, "nextToken": next_token},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def create(
    hub,
    ctx,
    model_package_group_name: str,
    model_package_group_description: str = None,
    tags: List = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Creates a model group. A model group contains a group of model versions.

    Args:
        model_package_group_name(str): The name of the model group.
        model_package_group_description(str, optional): A description for the model group. Defaults to None.
        tags(List, optional): A list of key value pairs associated with the model group. For more information, see Tagging Amazon Web Services resources in the Amazon Web Services General Reference Guide. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.sagemaker.model.package.group.init.create(
                ctx, model_package_group_name=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.sagemaker.model.package.group.init.create model_package_group_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="sagemaker",
        operation="create_model_package_group",
        op_kwargs={
            "ModelPackageGroupName": model_package_group_name,
            "ModelPackageGroupDescription": model_package_group_description,
            "Tags": tags,
        },
    )


async def delete(hub, ctx, model_package_group_name: str) -> None:
    r"""
    **Autogenerated function**

    Deletes the specified model group.

    Args:
        model_package_group_name(str): The name of the model group to delete.
    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.sagemaker.model.package.group.init.delete(
                ctx, model_package_group_name=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.sagemaker.model.package.group.init.delete model_package_group_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="sagemaker",
        operation="delete_model_package_group",
        op_kwargs={"ModelPackageGroupName": model_package_group_name},
    )


async def describe(hub, ctx, model_package_group_name: str) -> Dict:
    r"""
    **Autogenerated function**

    Gets a description for the specified model group.

    Args:
        model_package_group_name(str): The name of the model group to describe.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.sagemaker.model.package.group.init.describe(
                ctx, model_package_group_name=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.sagemaker.model.package.group.init.describe model_package_group_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="sagemaker",
        operation="describe_model_package_group",
        op_kwargs={"ModelPackageGroupName": model_package_group_name},
    )


async def list_all(
    hub,
    ctx,
    creation_time_after: str = None,
    creation_time_before: str = None,
    max_results: int = None,
    name_contains: str = None,
    next_token: str = None,
    sort_by: str = None,
    sort_order: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Gets a list of the model groups in your Amazon Web Services account.

    Args:
        creation_time_after(str, optional): A filter that returns only model groups created after the specified time. Defaults to None.
        creation_time_before(str, optional): A filter that returns only model groups created before the specified time. Defaults to None.
        max_results(int, optional): The maximum number of results to return in the response. Defaults to None.
        name_contains(str, optional): A string in the model group name. This filter returns only model groups whose name contains the specified string. Defaults to None.
        next_token(str, optional): If the result of the previous ListModelPackageGroups request was truncated, the response includes a NextToken. To retrieve the next set of model groups, use the token in the next request. Defaults to None.
        sort_by(str, optional): The field to sort results by. The default is CreationTime. Defaults to None.
        sort_order(str, optional): The sort order for results. The default is Ascending. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.sagemaker.model.package.group.init.list_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.sagemaker.model.package.group.init.list_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="sagemaker",
        operation="list_model_package_groups",
        op_kwargs={
            "CreationTimeAfter": creation_time_after,
            "CreationTimeBefore": creation_time_before,
            "MaxResults": max_results,
            "NameContains": name_contains,
            "NextToken": next_token,
            "SortBy": sort_by,
            "SortOrder": sort_order,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def get(hub, ctx, migration_id: str) -> Dict:
    r"""
    **Autogenerated function**

    Provides details about an ongoing or complete migration from an Amazon Lex V1 bot to an Amazon Lex V2 bot. Use this operation to view the migration alerts and warnings related to the migration.

    Args:
        migration_id(str): The unique identifier of the migration to view. The migrationID is returned by the operation.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.lex_model.migration.get(ctx, migration_id=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.lex_model.migration.get migration_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="lex-models",
        operation="get_migration",
        op_kwargs={"migrationId": migration_id},
    )


async def get_all(
    hub,
    ctx,
    sort_by_attribute: str = None,
    sort_by_order: str = None,
    v1_bot_name_contains: str = None,
    migration_status_equals: str = None,
    max_results: int = None,
    next_token: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Gets a list of migrations between Amazon Lex V1 and Amazon Lex V2.

    Args:
        sort_by_attribute(str, optional): The field to sort the list of migrations by. You can sort by the Amazon Lex V1 bot name or the date and time that the migration was started. Defaults to None.
        sort_by_order(str, optional): The order so sort the list. Defaults to None.
        v1_bot_name_contains(str, optional): Filters the list to contain only bots whose name contains the specified string. The string is matched anywhere in bot name. Defaults to None.
        migration_status_equals(str, optional): Filters the list to contain only migrations in the specified state. Defaults to None.
        max_results(int, optional): The maximum number of migrations to return in the response. The default is 10. Defaults to None.
        next_token(str, optional): A pagination token that fetches the next page of migrations. If the response to this operation is truncated, Amazon Lex returns a pagination token in the response. To fetch the next page of migrations, specify the pagination token in the request. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.lex_model.migration.get_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.lex_model.migration.get_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="lex-models",
        operation="get_migrations",
        op_kwargs={
            "sortByAttribute": sort_by_attribute,
            "sortByOrder": sort_by_order,
            "v1BotNameContains": v1_bot_name_contains,
            "migrationStatusEquals": migration_status_equals,
            "maxResults": max_results,
            "nextToken": next_token,
        },
    )


async def start(
    hub,
    ctx,
    v1_bot_name: str,
    v1_bot_version: str,
    v2_bot_name: str,
    v2_bot_role: str,
    migration_strategy: str,
) -> Dict:
    r"""
    **Autogenerated function**

    Starts migrating a bot from Amazon Lex V1 to Amazon Lex V2. Migrate your bot when you want to take advantage of the new features of Amazon Lex V2. For more information, see Migrating a bot in the Amazon Lex developer guide.

    Args:
        v1_bot_name(str): The name of the Amazon Lex V1 bot that you are migrating to Amazon Lex V2.
        v1_bot_version(str): The version of the bot to migrate to Amazon Lex V2. You can migrate the $LATEST version as well as any numbered version.
        v2_bot_name(str): The name of the Amazon Lex V2 bot that you are migrating the Amazon Lex V1 bot to.    If the Amazon Lex V2 bot doesn't exist, you must use the CREATE_NEW migration strategy.   If the Amazon Lex V2 bot exists, you must use the UPDATE_EXISTING migration strategy to change the contents of the Amazon Lex V2 bot.  .
        v2_bot_role(str): The IAM role that Amazon Lex uses to run the Amazon Lex V2 bot.
        migration_strategy(str): The strategy used to conduct the migration.    CREATE_NEW - Creates a new Amazon Lex V2 bot and migrates the Amazon Lex V1 bot to the new bot.    UPDATE_EXISTING - Overwrites the existing Amazon Lex V2 bot metadata and the locale being migrated. It doesn't change any other locales in the Amazon Lex V2 bot. If the locale doesn't exist, a new locale is created in the Amazon Lex V2 bot.  .

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.lex_model.migration.start(
                ctx,
                v1_bot_name=value,
                v1_bot_version=value,
                v2_bot_name=value,
                v2_bot_role=value,
                migration_strategy=value,
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.lex_model.migration.start v1_bot_name=value, v1_bot_version=value, v2_bot_name=value, v2_bot_role=value, migration_strategy=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="lex-models",
        operation="start_migration",
        op_kwargs={
            "v1BotName": v1_bot_name,
            "v1BotVersion": v1_bot_version,
            "v2BotName": v2_bot_name,
            "v2BotRole": v2_bot_role,
            "migrationStrategy": migration_strategy,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def update_multiple(hub, ctx, directory_id: str, desired_number: int) -> Dict:
    r"""
    **Autogenerated function**

    Adds or removes domain controllers to or from the directory. Based on the difference between current value and new value (provided through this API call), domain controllers will be added or removed. It may take up to 45 minutes for any new domain controllers to become fully active once the requested number of domain controllers is updated. During this time, you cannot make another update request.

    Args:
        directory_id(str): Identifier of the directory to which the domain controllers will be added or removed.
        desired_number(int): The number of domain controllers desired in the directory.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.ds.number_of_domain_controller.update_multiple(
                ctx, directory_id=value, desired_number=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.ds.number_of_domain_controller.update_multiple directory_id=value, desired_number=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="ds",
        operation="update_number_of_domain_controllers",
        op_kwargs={"DirectoryId": directory_id, "DesiredNumber": desired_number},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


__virtualname__ = "object"


async def delete(hub, ctx, path: str) -> Dict:
    r"""
    **Autogenerated function**

    Deletes an object at the specified path.

    Args:
        path(str): The path (including the file name) where the object is stored in the container. Format: <folder name>/<folder name>/<file name>.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.mediastore_data.object_.delete(ctx, path=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.mediastore_data.object.delete path=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="mediastore-data",
        operation="delete_object",
        op_kwargs={"Path": path},
    )


async def describe(hub, ctx, path: str) -> Dict:
    r"""
    **Autogenerated function**

    Gets the headers for an object at the specified path.

    Args:
        path(str): The path (including the file name) where the object is stored in the container. Format: <folder name>/<folder name>/<file name>.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.mediastore_data.object_.describe(ctx, path=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.mediastore_data.object.describe path=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="mediastore-data",
        operation="describe_object",
        op_kwargs={"Path": path},
    )


async def get(hub, ctx, path: str, range_: str = None) -> Dict:
    r"""
    **Autogenerated function**

    Downloads the object at the specified path. If the object’s upload availability is set to streaming, AWS Elemental MediaStore downloads the object even if it’s still uploading the object.

    Args:
        path(str): The path (including the file name) where the object is stored in the container. Format: <folder name>/<folder name>/<file name> For example, to upload the file mlaw.avi to the folder path premium\canada in the container movies, enter the path premium/canada/mlaw.avi. Do not include the container name in this path. If the path includes any folders that don't exist yet, the service creates them. For example, suppose you have an existing premium/usa subfolder. If you specify premium/canada, the service creates a canada subfolder in the premium folder. You then have two subfolders, usa and canada, in the premium folder.  There is no correlation between the path to the source and the path (folders) in the container in AWS Elemental MediaStore. For more information about folders and how they exist in a container, see the AWS Elemental MediaStore User Guide. The file name is the name that is assigned to the file that you upload. The file can have the same name inside and outside of AWS Elemental MediaStore, or it can have the same name. The file name can include or omit an extension. .
        range_(str, optional): The range bytes of an object to retrieve. For more information about the Range header, see http://www.w3.org/Protocols/rfc2616/rfc2616-sec14.html#sec14.35. AWS Elemental MediaStore ignores this header for partially uploaded objects that have streaming upload availability. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.mediastore_data.object_.get(ctx, path=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.mediastore_data.object.get path=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="mediastore-data",
        operation="get_object",
        op_kwargs={"Path": path, "Range": range_},
    )


async def put(
    hub,
    ctx,
    body: bytes,
    path: str,
    content_type: str = None,
    cache_control: str = None,
    storage_class: str = None,
    upload_availability: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Uploads an object to the specified path. Object sizes are limited to 25 MB for standard upload availability and 10 MB for streaming upload availability.

    Args:
        body(bytes): The bytes to be stored. .
        path(str): The path (including the file name) where the object is stored in the container. Format: <folder name>/<folder name>/<file name> For example, to upload the file mlaw.avi to the folder path premium\canada in the container movies, enter the path premium/canada/mlaw.avi. Do not include the container name in this path. If the path includes any folders that don't exist yet, the service creates them. For example, suppose you have an existing premium/usa subfolder. If you specify premium/canada, the service creates a canada subfolder in the premium folder. You then have two subfolders, usa and canada, in the premium folder.  There is no correlation between the path to the source and the path (folders) in the container in AWS Elemental MediaStore. For more information about folders and how they exist in a container, see the AWS Elemental MediaStore User Guide. The file name is the name that is assigned to the file that you upload. The file can have the same name inside and outside of AWS Elemental MediaStore, or it can have the same name. The file name can include or omit an extension. .
        content_type(str, optional): The content type of the object. Defaults to None.
        cache_control(str, optional): An optional CacheControl header that allows the caller to control the object's cache behavior. Headers can be passed in as specified in the HTTP at https://www.w3.org/Protocols/rfc2616/rfc2616-sec14.html#sec14.9. Headers with a custom user-defined value are also accepted. Defaults to None.
        storage_class(str, optional): Indicates the storage class of a Put request. Defaults to high-performance temporal storage class, and objects are persisted into durable storage shortly after being received. Defaults to None.
        upload_availability(str, optional): Indicates the availability of an object while it is still uploading. If the value is set to streaming, the object is available for downloading after some initial buffering but before the object is uploaded completely. If the value is set to standard, the object is available for downloading only when it is uploaded completely. The default value for this header is standard. To use this header, you must also set the HTTP Transfer-Encoding header to chunked. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.mediastore_data.object_.put(ctx, body=value, path=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.mediastore_data.object.put body=value, path=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="mediastore-data",
        operation="put_object",
        op_kwargs={
            "Body": body,
            "Path": path,
            "ContentType": content_type,
            "CacheControl": cache_control,
            "StorageClass": storage_class,
            "UploadAvailability": upload_availability,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


__func_alias__ = {"list_": "list"}


async def list_(
    hub, ctx, key_group_id: str, marker: str = None, max_items: str = None
) -> Dict:
    r"""
    **Autogenerated function**

    Gets a list of distribution IDs for distributions that have a cache behavior that references the specified key group. You can optionally specify the maximum number of items to receive in the response. If the total number of items in the list exceeds the maximum that you specify, or the default maximum, the response is paginated. To get the next page of items, send a subsequent request that specifies the NextMarker value from the current response as the Marker value in the subsequent request.

    Args:
        marker(str, optional): Use this field when paginating results to indicate where to begin in your list of distribution IDs. The response includes distribution IDs in the list that occur after the marker. To get the next page of the list, set this field’s value to the value of NextMarker from the current page’s response. Defaults to None.
        max_items(str, optional): The maximum number of distribution IDs that you want in the response. Defaults to None.
        key_group_id(str): The ID of the key group whose associated distribution IDs you are listing.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.cloudfront.distribution.by.key_group.list(
                ctx, key_group_id=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.cloudfront.distribution.by.key_group.list key_group_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="cloudfront",
        operation="list_distributions_by_key_group",
        op_kwargs={"Marker": marker, "MaxItems": max_items, "KeyGroupId": key_group_id},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def get_all(hub, ctx, log_group_name: str, time: int = None) -> Dict:
    r"""
    **Autogenerated function**

    Returns a list of the fields that are included in log events in the specified log group, along with the percentage of log events that contain each field. The search is limited to a time period that you specify. In the results, fields that start with @ are fields generated by CloudWatch Logs. For example, @timestamp is the timestamp of each log event. For more information about the fields that are generated by CloudWatch logs, see Supported Logs and Discovered Fields. The response results are sorted by the frequency percentage, starting with the highest percentage.

    Args:
        log_group_name(str): The name of the log group to search.
        time(int, optional): The time to set as the center of the query. If you specify time, the 15 minutes before this time are queries. If you omit time the 8 minutes before and 8 minutes after this time are searched. The time value is specified as epoch time, the number of seconds since January 1, 1970, 00:00:00 UTC. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.logs.log.group.field.get_all(ctx, log_group_name=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.logs.log.group.field.get_all log_group_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="logs",
        operation="get_log_group_fields",
        op_kwargs={"logGroupName": log_group_name, "time": time},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


__virtualname__ = "id_format"


async def describe(hub, ctx, resource: str = None) -> Dict:
    r"""
    **Autogenerated function**

    Describes the ID format settings for your resources on a per-Region basis, for example, to view which resource types are enabled for longer IDs. This request only returns information about resource types whose ID formats can be modified; it does not return information about other resource types. The following resource types support longer IDs: bundle | conversion-task | customer-gateway | dhcp-options | elastic-ip-allocation | elastic-ip-association | export-task | flow-log | image | import-task | instance | internet-gateway | network-acl | network-acl-association | network-interface | network-interface-attachment | prefix-list | reservation | route-table | route-table-association | security-group | snapshot | subnet | subnet-cidr-block-association | volume | vpc | vpc-cidr-block-association | vpc-endpoint | vpc-peering-connection | vpn-connection | vpn-gateway.  These settings apply to the IAM user who makes the request; they do not apply to the entire AWS account. By default, an IAM user defaults to the same settings as the root user, unless they explicitly override the settings by running the ModifyIdFormat command. Resources created with longer IDs are visible to all IAM users, regardless of these settings and provided that they have permission to use the relevant Describe command for the resource type.

    Args:
        resource(str, optional): The type of resource: bundle | conversion-task | customer-gateway | dhcp-options | elastic-ip-allocation | elastic-ip-association | export-task | flow-log | image | import-task | instance | internet-gateway | network-acl | network-acl-association | network-interface | network-interface-attachment | prefix-list | reservation | route-table | route-table-association | security-group | snapshot | subnet | subnet-cidr-block-association | volume | vpc | vpc-cidr-block-association | vpc-endpoint | vpc-peering-connection | vpn-connection | vpn-gateway . Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.ec2.id_format_.describe(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.ec2.id_format.describe
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="ec2",
        operation="describe_id_format",
        op_kwargs={"Resource": resource},
    )


async def modify(hub, ctx, resource: str, use_long_ids: bool) -> None:
    r"""
    **Autogenerated function**

    Modifies the ID format for the specified resource on a per-Region basis. You can specify that resources should receive longer IDs (17-character IDs) when they are created. This request can only be used to modify longer ID settings for resource types that are within the opt-in period. Resources currently in their opt-in period include: bundle | conversion-task | customer-gateway | dhcp-options | elastic-ip-allocation | elastic-ip-association | export-task | flow-log | image | import-task | internet-gateway | network-acl | network-acl-association | network-interface | network-interface-attachment | prefix-list | route-table | route-table-association | security-group | subnet | subnet-cidr-block-association | vpc | vpc-cidr-block-association | vpc-endpoint | vpc-peering-connection | vpn-connection | vpn-gateway. This setting applies to the IAM user who makes the request; it does not apply to the entire AWS account. By default, an IAM user defaults to the same settings as the root user. If you're using this action as the root user, then these settings apply to the entire account, unless an IAM user explicitly overrides these settings for themselves. For more information, see Resource IDs in the Amazon Elastic Compute Cloud User Guide. Resources created with longer IDs are visible to all IAM roles and users, regardless of these settings and provided that they have permission to use the relevant Describe command for the resource type.

    Args:
        resource(str): The type of resource: bundle | conversion-task | customer-gateway | dhcp-options | elastic-ip-allocation | elastic-ip-association | export-task | flow-log | image | import-task | internet-gateway | network-acl | network-acl-association | network-interface | network-interface-attachment | prefix-list | route-table | route-table-association | security-group | subnet | subnet-cidr-block-association | vpc | vpc-cidr-block-association | vpc-endpoint | vpc-peering-connection | vpn-connection | vpn-gateway. Alternatively, use the all-current option to include all resource types that are currently within their opt-in period for longer IDs.
        use_long_ids(bool): Indicate whether the resource should use longer IDs (17-character IDs).
    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.ec2.id_format_.modify(ctx, resource=value, use_long_ids=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.ec2.id_format.modify resource=value, use_long_ids=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="ec2",
        operation="modify_id_format",
        op_kwargs={"Resource": resource, "UseLongIds": use_long_ids},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


__func_alias__ = {"list_": "list"}


async def list_(
    hub, ctx, resource_arn: str, max_results: int = None, next_token: str = None
) -> Dict:
    r"""
    **Autogenerated function**

    Lists the tags that you associated with the specified resource.

    Args:
        resource_arn(str): The Amazon Resource Name (ARN) for the resource that you want to list tags for.
        max_results(int, optional): The maximum number of tags that you want to return in the response to a ListTagsForResource request. If you don't specify a value for MaxResults, Resolver returns up to 100 tags. Defaults to None.
        next_token(str, optional): For the first ListTagsForResource request, omit this value. If you have more than MaxResults tags, you can submit another ListTagsForResource request to get the next group of tags for the resource. In the next request, specify the value of NextToken from the previous response. . Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.route53resolver.tags_for_resource.list(ctx, resource_arn=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.route53resolver.tags_for_resource.list resource_arn=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="route53resolver",
        operation="list_tags_for_resource",
        op_kwargs={
            "ResourceArn": resource_arn,
            "MaxResults": max_results,
            "NextToken": next_token,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def disassociate(
    hub, ctx, portfolio_id: str, principal_arn: str, accept_language: str = None
) -> Dict:
    r"""
    **Autogenerated function**

    Disassociates a previously associated principal ARN from a specified portfolio.

    Args:
        accept_language(str, optional): The language code.    en - English (default)    jp - Japanese    zh - Chinese  . Defaults to None.
        portfolio_id(str): The portfolio identifier.
        principal_arn(str): The ARN of the principal (IAM user, role, or group).

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.servicecatalog.principal.from_portfolio.disassociate(
                ctx, portfolio_id=value, principal_arn=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.servicecatalog.principal.from_portfolio.disassociate portfolio_id=value, principal_arn=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="servicecatalog",
        operation="disassociate_principal_from_portfolio",
        op_kwargs={
            "AcceptLanguage": accept_language,
            "PortfolioId": portfolio_id,
            "PrincipalARN": principal_arn,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def send(hub, ctx, protocol: str) -> Dict:
    r"""
    **Autogenerated function**

    Sends a verification request to an email contact method to ensure it's owned by the requester. SMS contact methods don't need to be verified. A contact method is used to send you notifications about your Amazon Lightsail resources. You can add one email address and one mobile phone number contact method in each AWS Region. However, SMS text messaging is not supported in some AWS Regions, and SMS text messages cannot be sent to some countries/regions. For more information, see Notifications in Amazon Lightsail. A verification request is sent to the contact method when you initially create it. Use this action to send another verification request if a previous verification request was deleted, or has expired.  Notifications are not sent to an email contact method until after it is verified, and confirmed as valid.

    Args:
        protocol(str): The protocol to verify, such as Email or SMS (text messaging).

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.lightsail.contact_method.verification.send(ctx, protocol=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.lightsail.contact_method.verification.send protocol=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="lightsail",
        operation="send_contact_method_verification",
        op_kwargs={"protocol": protocol},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def get(hub, ctx, key_id: str) -> Dict:
    r"""
    **Autogenerated function**

    Gets a Boolean value that indicates whether automatic rotation of the key material is enabled for the specified customer master key (CMK). You cannot enable automatic rotation of asymmetric CMKs, CMKs with imported key material, or CMKs in a custom key store. To enable or disable automatic rotation of a set of related multi-Region keys, set the property on the primary key. The key rotation status for these CMKs is always false. The CMK that you use for this operation must be in a compatible key state. For details, see Key state: Effect on your CMK in the AWS Key Management Service Developer Guide.   Disabled: The key rotation status does not change when you disable a CMK. However, while the CMK is disabled, AWS KMS does not rotate the backing key.   Pending deletion: While a CMK is pending deletion, its key rotation status is false and AWS KMS does not rotate the backing key. If you cancel the deletion, the original key rotation status is restored.    Cross-account use: Yes. To perform this operation on a CMK in a different AWS account, specify the key ARN in the value of the KeyId parameter.  Required permissions: kms:GetKeyRotationStatus (key policy)  Related operations:     DisableKeyRotation     EnableKeyRotation

    Args:
        key_id(str): Gets the rotation status for the specified customer master key (CMK). Specify the key ID or key ARN of the CMK. To specify a CMK in a different AWS account, you must use the key ARN. For example:   Key ID: 1234abcd-12ab-34cd-56ef-1234567890ab    Key ARN: arn:aws:kms:us-east-2:111122223333:key/1234abcd-12ab-34cd-56ef-1234567890ab    To get the key ID and key ARN for a CMK, use ListKeys or DescribeKey.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.kms.key.rotation.status.get(ctx, key_id=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.kms.key.rotation.status.get key_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="kms",
        operation="get_key_rotation_status",
        op_kwargs={"KeyId": key_id},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def list_all(
    hub,
    ctx,
    start_time: str,
    end_time: str,
    thing_name: str = None,
    security_profile_name: str = None,
    behavior_criteria_type: str = None,
    list_suppressed_alerts: bool = None,
    next_token: str = None,
    max_results: int = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Lists the Device Defender security profile violations discovered during the given time period. You can use filters to limit the results to those alerts issued for a particular security profile, behavior, or thing (device).

    Args:
        start_time(str): The start time for the alerts to be listed.
        end_time(str): The end time for the alerts to be listed.
        thing_name(str, optional): A filter to limit results to those alerts caused by the specified thing. Defaults to None.
        security_profile_name(str, optional): A filter to limit results to those alerts generated by the specified security profile. Defaults to None.
        behavior_criteria_type(str, optional):  The criteria for a behavior. . Defaults to None.
        list_suppressed_alerts(bool, optional):  A list of all suppressed alerts. . Defaults to None.
        next_token(str, optional): The token for the next set of results. Defaults to None.
        max_results(int, optional): The maximum number of results to return at one time. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.iot.violation_event.list_all(
                ctx, start_time=value, end_time=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.iot.violation_event.list_all start_time=value, end_time=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="iot",
        operation="list_violation_events",
        op_kwargs={
            "startTime": start_time,
            "endTime": end_time,
            "thingName": thing_name,
            "securityProfileName": security_profile_name,
            "behaviorCriteriaType": behavior_criteria_type,
            "listSuppressedAlerts": list_suppressed_alerts,
            "nextToken": next_token,
            "maxResults": max_results,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def update_multiple(hub, ctx, certificate_arn: str, options: Dict) -> None:
    r"""
    **Autogenerated function**

    Updates a certificate. Currently, you can use this function to specify whether to opt in to or out of recording your certificate in a certificate transparency log. For more information, see  Opting Out of Certificate Transparency Logging.

    Args:
        certificate_arn(str): ARN of the requested certificate to update. This must be of the form:  arn:aws:acm:us-east-1:account:certificate/12345678-1234-1234-1234-123456789012  .
        options(Dict): Use to update the options for your certificate. Currently, you can specify whether to add your certificate to a transparency log. Certificate transparency makes it possible to detect SSL/TLS certificates that have been mistakenly or maliciously issued. Certificates that have not been logged typically produce an error message in a browser. .
    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.acm.certificate.option.update_multiple(
                ctx, certificate_arn=value, options=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.acm.certificate.option.update_multiple certificate_arn=value, options=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="acm",
        operation="update_certificate_options",
        op_kwargs={"CertificateArn": certificate_arn, "Options": options},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def create(
    hub,
    ctx,
    api_id: str,
    name: str,
    type_: str,
    description: str = None,
    service_role_arn: str = None,
    dynamodb_config: Dict = None,
    lambda_config: Dict = None,
    elasticsearch_config: Dict = None,
    http_config: Dict = None,
    relational_database_config: Dict = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Creates a DataSource object.

    Args:
        api_id(str): The API ID for the GraphQL API for the DataSource.
        name(str): A user-supplied name for the DataSource.
        description(str, optional): A description of the DataSource. Defaults to None.
        type_(str): The type of the DataSource.
        service_role_arn(str, optional): The Identity and Access Management service role ARN for the data source. The system assumes this role when accessing the data source. Defaults to None.
        dynamodb_config(Dict, optional): Amazon DynamoDB settings. Defaults to None.
        lambda_config(Dict, optional): Amazon Web Services Lambda settings. Defaults to None.
        elasticsearch_config(Dict, optional): Amazon Elasticsearch Service settings. Defaults to None.
        http_config(Dict, optional): HTTP endpoint settings. Defaults to None.
        relational_database_config(Dict, optional): Relational database settings. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.appsync.data_source.create(
                ctx, api_id=value, name=value, type_=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.appsync.data_source.create api_id=value, name=value, type_=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="appsync",
        operation="create_data_source",
        op_kwargs={
            "apiId": api_id,
            "name": name,
            "description": description,
            "type": type_,
            "serviceRoleArn": service_role_arn,
            "dynamodbConfig": dynamodb_config,
            "lambdaConfig": lambda_config,
            "elasticsearchConfig": elasticsearch_config,
            "httpConfig": http_config,
            "relationalDatabaseConfig": relational_database_config,
        },
    )


async def delete(hub, ctx, api_id: str, name: str) -> Dict:
    r"""
    **Autogenerated function**

    Deletes a DataSource object.

    Args:
        api_id(str): The API ID.
        name(str): The name of the data source.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.appsync.data_source.delete(ctx, api_id=value, name=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.appsync.data_source.delete api_id=value, name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="appsync",
        operation="delete_data_source",
        op_kwargs={"apiId": api_id, "name": name},
    )


async def get(hub, ctx, api_id: str, name: str) -> Dict:
    r"""
    **Autogenerated function**

    Retrieves a DataSource object.

    Args:
        api_id(str): The API ID.
        name(str): The name of the data source.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.appsync.data_source.get(ctx, api_id=value, name=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.appsync.data_source.get api_id=value, name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="appsync",
        operation="get_data_source",
        op_kwargs={"apiId": api_id, "name": name},
    )


async def list_all(
    hub, ctx, api_id: str, next_token: str = None, max_results: int = None
) -> Dict:
    r"""
    **Autogenerated function**

    Lists the data sources for a given API.

    Args:
        api_id(str): The API ID.
        next_token(str, optional): An identifier that was returned from the previous call to this operation, which can be used to return the next set of items in the list. . Defaults to None.
        max_results(int, optional): The maximum number of results you want the request to return. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.appsync.data_source.list_all(ctx, api_id=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.appsync.data_source.list_all api_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="appsync",
        operation="list_data_sources",
        op_kwargs={"apiId": api_id, "nextToken": next_token, "maxResults": max_results},
    )


async def update(
    hub,
    ctx,
    api_id: str,
    name: str,
    type_: str,
    description: str = None,
    service_role_arn: str = None,
    dynamodb_config: Dict = None,
    lambda_config: Dict = None,
    elasticsearch_config: Dict = None,
    http_config: Dict = None,
    relational_database_config: Dict = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Updates a DataSource object.

    Args:
        api_id(str): The API ID.
        name(str): The new name for the data source.
        description(str, optional): The new description for the data source. Defaults to None.
        type_(str): The new data source type.
        service_role_arn(str, optional): The new service role ARN for the data source. Defaults to None.
        dynamodb_config(Dict, optional): The new Amazon DynamoDB configuration. Defaults to None.
        lambda_config(Dict, optional): The new Amazon Web Services Lambda configuration. Defaults to None.
        elasticsearch_config(Dict, optional): The new Elasticsearch Service configuration. Defaults to None.
        http_config(Dict, optional): The new HTTP endpoint configuration. Defaults to None.
        relational_database_config(Dict, optional): The new relational database configuration. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.appsync.data_source.update(
                ctx, api_id=value, name=value, type_=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.appsync.data_source.update api_id=value, name=value, type_=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="appsync",
        operation="update_data_source",
        op_kwargs={
            "apiId": api_id,
            "name": name,
            "description": description,
            "type": type_,
            "serviceRoleArn": service_role_arn,
            "dynamodbConfig": dynamodb_config,
            "lambdaConfig": lambda_config,
            "elasticsearchConfig": elasticsearch_config,
            "httpConfig": http_config,
            "relationalDatabaseConfig": relational_database_config,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def describe(
    hub,
    ctx,
    metric_name: str,
    namespace: str,
    statistic: str = None,
    extended_statistic: str = None,
    dimensions: List = None,
    period: int = None,
    unit: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Retrieves the alarms for the specified metric. To filter the results, specify a statistic, period, or unit. This operation retrieves only standard alarms that are based on the specified metric. It does not return alarms based on math expressions that use the specified metric, or composite alarms that use the specified metric.

    Args:
        metric_name(str): The name of the metric.
        namespace(str): The namespace of the metric.
        statistic(str, optional): The statistic for the metric, other than percentiles. For percentile statistics, use ExtendedStatistics. Defaults to None.
        extended_statistic(str, optional): The percentile statistic for the metric. Specify a value between p0.0 and p100. Defaults to None.
        dimensions(List, optional): The dimensions associated with the metric. If the metric has any associated dimensions, you must specify them in order for the call to succeed. Defaults to None.
        period(int, optional): The period, in seconds, over which the statistic is applied. Defaults to None.
        unit(str, optional): The unit for the metric. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.cloudwatch.alarm.for_metric.describe(
                ctx, metric_name=value, namespace=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.cloudwatch.alarm.for_metric.describe metric_name=value, namespace=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="cloudwatch",
        operation="describe_alarms_for_metric",
        op_kwargs={
            "MetricName": metric_name,
            "Namespace": namespace,
            "Statistic": statistic,
            "ExtendedStatistic": extended_statistic,
            "Dimensions": dimensions,
            "Period": period,
            "Unit": unit,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def get(hub, ctx, job_id: str, api_version: str = None) -> Dict:
    r"""
    **Autogenerated function**

    This operation returns information about a job, including where the job is in the processing pipeline, the status of the results, and the signature value associated with the job. You can only return information about jobs you own.

    Args:
        job_id(str): A unique identifier which refers to a particular job.
        api_version(str, optional): Specifies the version of the client tool. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.importexport.status.get(ctx, job_id=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.importexport.status.get job_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="importexport",
        operation="get_status",
        op_kwargs={"JobId": job_id, "APIVersion": api_version},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def update(
    hub,
    ctx,
    current_version: str,
    operation: str,
    data_retention_change_in_hours: int,
    stream_name: str = None,
    stream_arn: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

     Increases or decreases the stream's data retention period by the value that you specify. To indicate whether you want to increase or decrease the data retention period, specify the Operation parameter in the request body. In the request, you must specify either the StreamName or the StreamARN.   The retention period that you specify replaces the current value.  This operation requires permission for the KinesisVideo:UpdateDataRetention action. Changing the data retention period affects the data in the stream as follows:   If the data retention period is increased, existing data is retained for the new retention period. For example, if the data retention period is increased from one hour to seven hours, all existing data is retained for seven hours.   If the data retention period is decreased, existing data is retained for the new retention period. For example, if the data retention period is decreased from seven hours to one hour, all existing data is retained for one hour, and any data older than one hour is deleted immediately.

    Args:
        stream_name(str, optional): The name of the stream whose retention period you want to change. Defaults to None.
        stream_arn(str, optional): The Amazon Resource Name (ARN) of the stream whose retention period you want to change. Defaults to None.
        current_version(str): The version of the stream whose retention period you want to change. To get the version, call either the DescribeStream or the ListStreams API.
        operation(str): Indicates whether you want to increase or decrease the retention period.
        data_retention_change_in_hours(int): The retention period, in hours. The value you specify replaces the current value. The maximum value for this parameter is 87600 (ten years).

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.kinesisvideo.data.retention.update(
                ctx, current_version=value, operation=value, data_retention_change_in_hours=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.kinesisvideo.data.retention.update current_version=value, operation=value, data_retention_change_in_hours=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="kinesisvideo",
        operation="update_data_retention",
        op_kwargs={
            "StreamName": stream_name,
            "StreamARN": stream_arn,
            "CurrentVersion": current_version,
            "Operation": operation,
            "DataRetentionChangeInHours": data_retention_change_in_hours,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def create(
    hub, ctx, policy_arn: str, policy_document: str, set_as_default: bool = None
) -> Dict:
    r"""
    **Autogenerated function**

    Creates a new version of the specified managed policy. To update a managed policy, you create a new policy version. A managed policy can have up to five versions. If the policy has five versions, you must delete an existing version using DeletePolicyVersion before you create a new version. Optionally, you can set the new version as the policy's default version. The default version is the version that is in effect for the IAM users, groups, and roles to which the policy is attached. For more information about managed policy versions, see Versioning for managed policies in the IAM User Guide.

    Args:
        policy_arn(str): The Amazon Resource Name (ARN) of the IAM policy to which you want to add a new version. For more information about ARNs, see Amazon Resource Names (ARNs) in the Amazon Web Services General Reference.
        policy_document(str): The JSON policy document that you want to use as the content for this new version of the policy. You must provide policies in JSON format in IAM. However, for CloudFormation templates formatted in YAML, you can provide the policy in JSON or YAML format. CloudFormation always converts a YAML policy to JSON format before submitting it to IAM. The maximum length of the policy document that you can pass in this operation, including whitespace, is listed below. To view the maximum character counts of a managed policy with no whitespaces, see IAM and STS character quotas. The regex pattern used to validate this parameter is a string of characters consisting of the following:   Any printable ASCII character ranging from the space character (\u0020) through the end of the ASCII character range   The printable characters in the Basic Latin and Latin-1 Supplement character set (through \u00FF)   The special characters tab (\u0009), line feed (\u000A), and carriage return (\u000D)  .
        set_as_default(bool, optional): Specifies whether to set this version as the policy's default version. When this parameter is true, the new policy version becomes the operative version. That is, it becomes the version that is in effect for the IAM users, groups, and roles that the policy is attached to. For more information about managed policy versions, see Versioning for managed policies in the IAM User Guide. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.iam.policy.version.create(
                ctx, policy_arn=value, policy_document=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.iam.policy.version.create policy_arn=value, policy_document=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="iam",
        operation="create_policy_version",
        op_kwargs={
            "PolicyArn": policy_arn,
            "PolicyDocument": policy_document,
            "SetAsDefault": set_as_default,
        },
    )


async def delete(hub, ctx, policy_arn: str, version_id: str) -> None:
    r"""
    **Autogenerated function**

    Deletes the specified version from the specified managed policy. You cannot delete the default version from a policy using this operation. To delete the default version from a policy, use DeletePolicy. To find out which version of a policy is marked as the default version, use ListPolicyVersions. For information about versions for managed policies, see Versioning for managed policies in the IAM User Guide.

    Args:
        policy_arn(str): The Amazon Resource Name (ARN) of the IAM policy from which you want to delete a version. For more information about ARNs, see Amazon Resource Names (ARNs) in the Amazon Web Services General Reference.
        version_id(str): The policy version to delete. This parameter allows (through its regex pattern) a string of characters that consists of the lowercase letter 'v' followed by one or two digits, and optionally followed by a period '.' and a string of letters and digits. For more information about managed policy versions, see Versioning for managed policies in the IAM User Guide.
    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.iam.policy.version.delete(
                ctx, policy_arn=value, version_id=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.iam.policy.version.delete policy_arn=value, version_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="iam",
        operation="delete_policy_version",
        op_kwargs={"PolicyArn": policy_arn, "VersionId": version_id},
    )


async def get(hub, ctx, policy_arn: str, version_id: str) -> Dict:
    r"""
    **Autogenerated function**

    Retrieves information about the specified version of the specified managed policy, including the policy document.  Policies returned by this operation are URL-encoded compliant with RFC 3986. You can use a URL decoding method to convert the policy back to plain JSON text. For example, if you use Java, you can use the decode method of the java.net.URLDecoder utility class in the Java SDK. Other languages and SDKs provide similar functionality.  To list the available versions for a policy, use ListPolicyVersions. This operation retrieves information about managed policies. To retrieve information about an inline policy that is embedded in a user, group, or role, use GetUserPolicy, GetGroupPolicy, or GetRolePolicy. For more information about the types of policies, see Managed policies and inline policies in the IAM User Guide. For more information about managed policy versions, see Versioning for managed policies in the IAM User Guide.

    Args:
        policy_arn(str): The Amazon Resource Name (ARN) of the managed policy that you want information about. For more information about ARNs, see Amazon Resource Names (ARNs) in the Amazon Web Services General Reference.
        version_id(str): Identifies the policy version to retrieve. This parameter allows (through its regex pattern) a string of characters that consists of the lowercase letter 'v' followed by one or two digits, and optionally followed by a period '.' and a string of letters and digits.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.iam.policy.version.get(ctx, policy_arn=value, version_id=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.iam.policy.version.get policy_arn=value, version_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="iam",
        operation="get_policy_version",
        op_kwargs={"PolicyArn": policy_arn, "VersionId": version_id},
    )


async def list_all(
    hub, ctx, policy_arn: str, marker: str = None, max_items: int = None
) -> Dict:
    r"""
    **Autogenerated function**

    Lists information about the versions of the specified managed policy, including the version that is currently set as the policy's default version. For more information about managed policies, see Managed policies and inline policies in the IAM User Guide.

    Args:
        policy_arn(str): The Amazon Resource Name (ARN) of the IAM policy for which you want the versions. For more information about ARNs, see Amazon Resource Names (ARNs) in the Amazon Web Services General Reference.
        marker(str, optional): Use this parameter only when paginating results and only after you receive a response indicating that the results are truncated. Set it to the value of the Marker element in the response that you received to indicate where the next call should start. Defaults to None.
        max_items(int, optional): Use this only when paginating results to indicate the maximum number of items you want in the response. If additional items exist beyond the maximum you specify, the IsTruncated response element is true. If you do not include this parameter, the number of items defaults to 100. Note that IAM might return fewer results, even when there are more results available. In that case, the IsTruncated response element returns true, and Marker contains a value to include in the subsequent call that tells the service where to continue from. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.iam.policy.version.list_all(ctx, policy_arn=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.iam.policy.version.list_all policy_arn=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="iam",
        operation="list_policy_versions",
        op_kwargs={"PolicyArn": policy_arn, "Marker": marker, "MaxItems": max_items},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def disable(hub, ctx, dry_run: bool = None) -> Dict:
    r"""
    **Autogenerated function**

    Disables EBS encryption by default for your account in the current Region. After you disable encryption by default, you can still create encrypted volumes by enabling encryption when you create each volume. Disabling encryption by default does not change the encryption status of your existing volumes. For more information, see Amazon EBS encryption in the Amazon Elastic Compute Cloud User Guide.

    Args:
        dry_run(bool, optional): Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.ec2.ebs.encryption_by_default.disable(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.ec2.ebs.encryption_by_default.disable
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="ec2",
        operation="disable_ebs_encryption_by_default",
        op_kwargs={"DryRun": dry_run},
    )


async def enable(hub, ctx, dry_run: bool = None) -> Dict:
    r"""
    **Autogenerated function**

    Enables EBS encryption by default for your account in the current Region. After you enable encryption by default, the EBS volumes that you create are always encrypted, either using the default KMS key or the KMS key that you specified when you created each volume. For more information, see Amazon EBS encryption in the Amazon Elastic Compute Cloud User Guide. You can specify the default KMS key for encryption by default using ModifyEbsDefaultKmsKeyId or ResetEbsDefaultKmsKeyId. Enabling encryption by default has no effect on the encryption status of your existing volumes. After you enable encryption by default, you can no longer launch instances using instance types that do not support encryption. For more information, see Supported instance types.

    Args:
        dry_run(bool, optional): Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.ec2.ebs.encryption_by_default.enable(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.ec2.ebs.encryption_by_default.enable
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="ec2",
        operation="enable_ebs_encryption_by_default",
        op_kwargs={"DryRun": dry_run},
    )


async def get(hub, ctx, dry_run: bool = None) -> Dict:
    r"""
    **Autogenerated function**

    Describes whether EBS encryption by default is enabled for your account in the current Region. For more information, see Amazon EBS encryption in the Amazon Elastic Compute Cloud User Guide.

    Args:
        dry_run(bool, optional): Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.ec2.ebs.encryption_by_default.get(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.ec2.ebs.encryption_by_default.get
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="ec2",
        operation="get_ebs_encryption_by_default",
        op_kwargs={"DryRun": dry_run},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def get(
    hub, ctx, configuration_aggregator_name: str, resource_identifier: Dict
) -> Dict:
    r"""
    **Autogenerated function**

    Returns configuration item that is aggregated for your specific resource in a specific source account and region.

    Args:
        configuration_aggregator_name(str): The name of the configuration aggregator.
        resource_identifier(Dict): An object that identifies aggregate resource.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.config.aggregate.resource_config.get(
                ctx, configuration_aggregator_name=value, resource_identifier=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.config.aggregate.resource_config.get configuration_aggregator_name=value, resource_identifier=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="config",
        operation="get_aggregate_resource_config",
        op_kwargs={
            "ConfigurationAggregatorName": configuration_aggregator_name,
            "ResourceIdentifier": resource_identifier,
        },
    )


async def select(
    hub,
    ctx,
    expression: str,
    configuration_aggregator_name: str,
    limit: int = None,
    max_results: int = None,
    next_token: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Accepts a structured query language (SQL) SELECT command and an aggregator to query configuration state of AWS resources across multiple accounts and regions, performs the corresponding search, and returns resource configurations matching the properties. For more information about query components, see the  Query Components  section in the AWS Config Developer Guide.

    Args:
        expression(str): The SQL query SELECT command. .
        configuration_aggregator_name(str): The name of the configuration aggregator.
        limit(int, optional): The maximum number of query results returned on each page. . Defaults to None.
        max_results(int, optional): The maximum number of query results returned on each page. AWS Config also allows the Limit request parameter. Defaults to None.
        next_token(str, optional): The nextToken string returned in a previous request that you use to request the next page of results in a paginated response. . Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.config.aggregate.resource_config.select(
                ctx, expression=value, configuration_aggregator_name=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.config.aggregate.resource_config.select expression=value, configuration_aggregator_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="config",
        operation="select_aggregate_resource_config",
        op_kwargs={
            "Expression": expression,
            "ConfigurationAggregatorName": configuration_aggregator_name,
            "Limit": limit,
            "MaxResults": max_results,
            "NextToken": next_token,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def cancel(hub, ctx, pipeline_name: str, reprocessing_id: str) -> Dict:
    r"""
    **Autogenerated function**

    Cancels the reprocessing of data through the pipeline.

    Args:
        pipeline_name(str): The name of pipeline for which data reprocessing is canceled.
        reprocessing_id(str): The ID of the reprocessing task (returned by StartPipelineReprocessing).

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.iotanalytic.pipeline.reprocessing.cancel(
                ctx, pipeline_name=value, reprocessing_id=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.iotanalytic.pipeline.reprocessing.cancel pipeline_name=value, reprocessing_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="iotanalytics",
        operation="cancel_pipeline_reprocessing",
        op_kwargs={"pipelineName": pipeline_name, "reprocessingId": reprocessing_id},
    )


async def start(
    hub,
    ctx,
    pipeline_name: str,
    start_time: str = None,
    end_time: str = None,
    channel_messages: Dict = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Starts the reprocessing of raw message data through the pipeline.

    Args:
        pipeline_name(str): The name of the pipeline on which to start reprocessing.
        start_time(str, optional): The start time (inclusive) of raw message data that is reprocessed. If you specify a value for the startTime parameter, you must not use the channelMessages object. Defaults to None.
        end_time(str, optional): The end time (exclusive) of raw message data that is reprocessed. If you specify a value for the endTime parameter, you must not use the channelMessages object. Defaults to None.
        channel_messages(Dict, optional): Specifies one or more sets of channel messages that you want to reprocess. If you use the channelMessages object, you must not specify a value for startTime and endTime. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.iotanalytic.pipeline.reprocessing.start(
                ctx, pipeline_name=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.iotanalytic.pipeline.reprocessing.start pipeline_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="iotanalytics",
        operation="start_pipeline_reprocessing",
        op_kwargs={
            "pipelineName": pipeline_name,
            "startTime": start_time,
            "endTime": end_time,
            "channelMessages": channel_messages,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def get(hub, ctx, bot_name: str, bot_versions: List, status_type: str) -> Dict:
    r"""
    **Autogenerated function**

    Use the GetUtterancesView operation to get information about the utterances that your users have made to your bot. You can use this list to tune the utterances that your bot responds to. For example, say that you have created a bot to order flowers. After your users have used your bot for a while, use the GetUtterancesView operation to see the requests that they have made and whether they have been successful. You might find that the utterance "I want flowers" is not being recognized. You could add this utterance to the OrderFlowers intent so that your bot recognizes that utterance. After you publish a new version of a bot, you can get information about the old version and the new so that you can compare the performance across the two versions.  Utterance statistics are generated once a day. Data is available for the last 15 days. You can request information for up to 5 versions of your bot in each request. Amazon Lex returns the most frequent utterances received by the bot in the last 15 days. The response contains information about a maximum of 100 utterances for each version. If you set childDirected field to true when you created your bot, if you are using slot obfuscation with one or more slots, or if you opted out of participating in improving Amazon Lex, utterances are not available. This operation requires permissions for the lex:GetUtterancesView action.

    Args:
        bot_name(str): The name of the bot for which utterance information should be returned.
        bot_versions(List): An array of bot versions for which utterance information should be returned. The limit is 5 versions per request.
        status_type(str): To return utterances that were recognized and handled, use Detected. To return utterances that were not recognized, use Missed.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.lex_model.utterance.view.get(
                ctx, bot_name=value, bot_versions=value, status_type=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.lex_model.utterance.view.get bot_name=value, bot_versions=value, status_type=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="lex-models",
        operation="get_utterances_view",
        op_kwargs={
            "botName": bot_name,
            "botVersions": bot_versions,
            "statusType": status_type,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def create(
    hub,
    ctx,
    accelerator_arn: str,
    port_ranges: List,
    protocol: str,
    idempotency_token: str,
    client_affinity: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Create a listener to process inbound connections from clients to an accelerator. Connections arrive to assigned static IP addresses on a port, port range, or list of port ranges that you specify.

    Args:
        accelerator_arn(str): The Amazon Resource Name (ARN) of your accelerator.
        port_ranges(List): The list of port ranges to support for connections from clients to your accelerator.
        protocol(str): The protocol for connections from clients to your accelerator.
        client_affinity(str, optional): Client affinity lets you direct all requests from a user to the same endpoint, if you have stateful applications, regardless of the port and protocol of the client request. Client affinity gives you control over whether to always route each client to the same specific endpoint. AWS Global Accelerator uses a consistent-flow hashing algorithm to choose the optimal endpoint for a connection. If client affinity is NONE, Global Accelerator uses the "five-tuple" (5-tuple) properties—source IP address, source port, destination IP address, destination port, and protocol—to select the hash value, and then chooses the best endpoint. However, with this setting, if someone uses different ports to connect to Global Accelerator, their connections might not be always routed to the same endpoint because the hash value changes.  If you want a given client to always be routed to the same endpoint, set client affinity to SOURCE_IP instead. When you use the SOURCE_IP setting, Global Accelerator uses the "two-tuple" (2-tuple) properties— source (client) IP address and destination IP address—to select the hash value. The default value is NONE. Defaults to None.
        idempotency_token(str): A unique, case-sensitive identifier that you provide to ensure the idempotency—that is, the uniqueness—of the request.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.globalaccelerator.listener.create(
                ctx,
                accelerator_arn=value,
                port_ranges=value,
                protocol=value,
                idempotency_token=value,
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.globalaccelerator.listener.create accelerator_arn=value, port_ranges=value, protocol=value, idempotency_token=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="globalaccelerator",
        operation="create_listener",
        op_kwargs={
            "AcceleratorArn": accelerator_arn,
            "PortRanges": port_ranges,
            "Protocol": protocol,
            "ClientAffinity": client_affinity,
            "IdempotencyToken": idempotency_token,
        },
    )


async def delete(hub, ctx, listener_arn: str) -> None:
    r"""
    **Autogenerated function**

    Delete a listener from an accelerator.

    Args:
        listener_arn(str): The Amazon Resource Name (ARN) of the listener.
    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.globalaccelerator.listener.delete(ctx, listener_arn=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.globalaccelerator.listener.delete listener_arn=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="globalaccelerator",
        operation="delete_listener",
        op_kwargs={"ListenerArn": listener_arn},
    )


async def describe(hub, ctx, listener_arn: str) -> Dict:
    r"""
    **Autogenerated function**

    Describe a listener.

    Args:
        listener_arn(str): The Amazon Resource Name (ARN) of the listener to describe.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.globalaccelerator.listener.describe(ctx, listener_arn=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.globalaccelerator.listener.describe listener_arn=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="globalaccelerator",
        operation="describe_listener",
        op_kwargs={"ListenerArn": listener_arn},
    )


async def list_all(
    hub, ctx, accelerator_arn: str, max_results: int = None, next_token: str = None
) -> Dict:
    r"""
    **Autogenerated function**

    List the listeners for an accelerator.

    Args:
        accelerator_arn(str): The Amazon Resource Name (ARN) of the accelerator for which you want to list listener objects.
        max_results(int, optional): The number of listener objects that you want to return with this call. The default value is 10. Defaults to None.
        next_token(str, optional): The token for the next set of results. You receive this token from a previous call. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.globalaccelerator.listener.list_all(ctx, accelerator_arn=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.globalaccelerator.listener.list_all accelerator_arn=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="globalaccelerator",
        operation="list_listeners",
        op_kwargs={
            "AcceleratorArn": accelerator_arn,
            "MaxResults": max_results,
            "NextToken": next_token,
        },
    )


async def update(
    hub,
    ctx,
    listener_arn: str,
    port_ranges: List = None,
    protocol: str = None,
    client_affinity: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Update a listener.

    Args:
        listener_arn(str): The Amazon Resource Name (ARN) of the listener to update.
        port_ranges(List, optional): The updated list of port ranges for the connections from clients to the accelerator. Defaults to None.
        protocol(str, optional): The updated protocol for the connections from clients to the accelerator. Defaults to None.
        client_affinity(str, optional): Client affinity lets you direct all requests from a user to the same endpoint, if you have stateful applications, regardless of the port and protocol of the client request. Client affinity gives you control over whether to always route each client to the same specific endpoint. AWS Global Accelerator uses a consistent-flow hashing algorithm to choose the optimal endpoint for a connection. If client affinity is NONE, Global Accelerator uses the "five-tuple" (5-tuple) properties—source IP address, source port, destination IP address, destination port, and protocol—to select the hash value, and then chooses the best endpoint. However, with this setting, if someone uses different ports to connect to Global Accelerator, their connections might not be always routed to the same endpoint because the hash value changes.  If you want a given client to always be routed to the same endpoint, set client affinity to SOURCE_IP instead. When you use the SOURCE_IP setting, Global Accelerator uses the "two-tuple" (2-tuple) properties— source (client) IP address and destination IP address—to select the hash value. The default value is NONE. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.globalaccelerator.listener.update(ctx, listener_arn=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.globalaccelerator.listener.update listener_arn=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="globalaccelerator",
        operation="update_listener",
        op_kwargs={
            "ListenerArn": listener_arn,
            "PortRanges": port_ranges,
            "Protocol": protocol,
            "ClientAffinity": client_affinity,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def describe(hub, ctx, fleet_arn: str) -> Dict:
    r"""
    **Autogenerated function**

    Describes the configuration for delivering audit streams to the customer account.

    Args:
        fleet_arn(str): The ARN of the fleet.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.worklink.audit_stream_configuration.describe(
                ctx, fleet_arn=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.worklink.audit_stream_configuration.describe fleet_arn=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="worklink",
        operation="describe_audit_stream_configuration",
        op_kwargs={"FleetArn": fleet_arn},
    )


async def update(hub, ctx, fleet_arn: str, audit_stream_arn: str = None) -> Dict:
    r"""
    **Autogenerated function**

    Updates the audit stream configuration for the fleet.

    Args:
        fleet_arn(str): The ARN of the fleet.
        audit_stream_arn(str, optional): The ARN of the Amazon Kinesis data stream that receives the audit events. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.worklink.audit_stream_configuration.update(ctx, fleet_arn=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.worklink.audit_stream_configuration.update fleet_arn=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="worklink",
        operation="update_audit_stream_configuration",
        op_kwargs={"FleetArn": fleet_arn, "AuditStreamArn": audit_stream_arn},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def describe_all(hub, ctx, workspace_id: str) -> Dict:
    r"""
    **Autogenerated function**

    Describes the snapshots for the specified WorkSpace.

    Args:
        workspace_id(str): The identifier of the WorkSpace.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.workspace.workspace.snapshot.describe_all(
                ctx, workspace_id=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.workspace.workspace.snapshot.describe_all workspace_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="workspaces",
        operation="describe_workspace_snapshots",
        op_kwargs={"WorkspaceId": workspace_id},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def delete(hub, ctx, gateway_arn: str) -> Dict:
    r"""
    **Autogenerated function**

    Deletes the automatic tape creation policy of a gateway. If you delete this policy, new virtual tapes must be created manually. Use the Amazon Resource Name (ARN) of the gateway in your request to remove the policy.

    Args:
        gateway_arn(str): The Amazon Resource Name (ARN) of the gateway. Use the ListGateways operation to return a list of gateways for your account and Region.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.storagegateway.automatic_tape_creation_policy.delete(
                ctx, gateway_arn=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.storagegateway.automatic_tape_creation_policy.delete gateway_arn=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="storagegateway",
        operation="delete_automatic_tape_creation_policy",
        op_kwargs={"GatewayARN": gateway_arn},
    )


async def list_all(hub, ctx, gateway_arn: str = None) -> Dict:
    r"""
    **Autogenerated function**

    Lists the automatic tape creation policies for a gateway. If there are no automatic tape creation policies for the gateway, it returns an empty list. This operation is only supported for tape gateways.

    Args:
        gateway_arn(str, optional): The Amazon Resource Name (ARN) of the gateway. Use the ListGateways operation to return a list of gateways for your account and Region. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.storagegateway.automatic_tape_creation_policy.list_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.storagegateway.automatic_tape_creation_policy.list_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="storagegateway",
        operation="list_automatic_tape_creation_policies",
        op_kwargs={"GatewayARN": gateway_arn},
    )


async def update(
    hub, ctx, automatic_tape_creation_rules: List, gateway_arn: str
) -> Dict:
    r"""
    **Autogenerated function**

    Updates the automatic tape creation policy of a gateway. Use this to update the policy with a new set of automatic tape creation rules. This is only supported for tape gateways. By default, there is no automatic tape creation policy.  A gateway can have only one automatic tape creation policy.

    Args:
        automatic_tape_creation_rules(List): An automatic tape creation policy consists of a list of automatic tape creation rules. The rules determine when and how to automatically create new tapes.
        gateway_arn(str): The Amazon Resource Name (ARN) of the gateway. Use the ListGateways operation to return a list of gateways for your account and Region.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.storagegateway.automatic_tape_creation_policy.update(
                ctx, automatic_tape_creation_rules=value, gateway_arn=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.storagegateway.automatic_tape_creation_policy.update automatic_tape_creation_rules=value, gateway_arn=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="storagegateway",
        operation="update_automatic_tape_creation_policy",
        op_kwargs={
            "AutomaticTapeCreationRules": automatic_tape_creation_rules,
            "GatewayARN": gateway_arn,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def update(hub, ctx, hit_id: str, revert: bool = None) -> Dict:
    r"""
    **Autogenerated function**

     The UpdateHITReviewStatus operation updates the status of a HIT. If the status is Reviewable, this operation can update the status to Reviewing, or it can revert a Reviewing HIT back to the Reviewable status.

    Args:
        hit_id(str):  The ID of the HIT to update. .
        revert(bool, optional):  Specifies how to update the HIT status. Default is False.     Setting this to false will only transition a HIT from Reviewable to Reviewing     Setting this to true will only transition a HIT from Reviewing to Reviewable   . Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.mturk.hit.review_status.update(ctx, hit_id=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.mturk.hit.review_status.update hit_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="mturk",
        operation="update_hit_review_status",
        op_kwargs={"HITId": hit_id, "Revert": revert},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


__func_alias__ = {"import_": "import"}


async def get(hub, ctx, certificate_authority_arn: str) -> Dict:
    r"""
    **Autogenerated function**

    Retrieves the certificate and certificate chain for your private certificate authority (CA) or one that has been shared with you. Both the certificate and the chain are base64 PEM-encoded. The chain does not include the CA certificate. Each certificate in the chain signs the one before it.

    Args:
        certificate_authority_arn(str): The Amazon Resource Name (ARN) of your private CA. This is of the form:  arn:aws:acm-pca:region:account:certificate-authority/12345678-1234-1234-1234-123456789012 . .

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.acm_pca.certificate.authority.certificate.get(ctx, certificate_authority_arn=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.acm_pca.certificate.authority.certificate.get certificate_authority_arn=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="acm-pca",
        operation="get_certificate_authority_certificate",
        op_kwargs={"CertificateAuthorityArn": certificate_authority_arn},
    )


async def import_(
    hub,
    ctx,
    certificate_authority_arn: str,
    certificate: bytes,
    certificate_chain: bytes = None,
) -> None:
    r"""
    **Autogenerated function**

    Imports a signed private CA certificate into ACM Private CA. This action is used when you are using a chain of trust whose root is located outside ACM Private CA. Before you can call this action, the following preparations must in place:   In ACM Private CA, call the CreateCertificateAuthority action to create the private CA that you plan to back with the imported certificate.   Call the GetCertificateAuthorityCsr action to generate a certificate signing request (CSR).   Sign the CSR using a root or intermediate CA hosted by either an on-premises PKI hierarchy or by a commercial CA.   Create a certificate chain and copy the signed certificate and the certificate chain to your working directory.   ACM Private CA supports three scenarios for installing a CA certificate:   Installing a certificate for a root CA hosted by ACM Private CA.   Installing a subordinate CA certificate whose parent authority is hosted by ACM Private CA.   Installing a subordinate CA certificate whose parent authority is externally hosted.   The following additional requirements apply when you import a CA certificate.   Only a self-signed certificate can be imported as a root CA.   A self-signed certificate cannot be imported as a subordinate CA.   Your certificate chain must not include the private CA certificate that you are importing.   Your root CA must be the last certificate in your chain. The subordinate certificate, if any, that your root CA signed must be next to last. The subordinate certificate signed by the preceding subordinate CA must come next, and so on until your chain is built.    The chain must be PEM-encoded.   The maximum allowed size of a certificate is 32 KB.   The maximum allowed size of a certificate chain is 2 MB.    Enforcement of Critical Constraints  ACM Private CA allows the following extensions to be marked critical in the imported CA certificate or chain.   Basic constraints (must be marked critical)   Subject alternative names   Key usage   Extended key usage   Authority key identifier   Subject key identifier   Issuer alternative name   Subject directory attributes   Subject information access   Certificate policies   Policy mappings   Inhibit anyPolicy   ACM Private CA rejects the following extensions when they are marked critical in an imported CA certificate or chain.   Name constraints   Policy constraints   CRL distribution points   Authority information access   Freshest CRL   Any other extension

    Args:
        certificate_authority_arn(str): The Amazon Resource Name (ARN) that was returned when you called CreateCertificateAuthority. This must be of the form:   arn:aws:acm-pca:region:account:certificate-authority/12345678-1234-1234-1234-123456789012  .
        certificate(bytes): The PEM-encoded certificate for a private CA. This may be a self-signed certificate in the case of a root CA, or it may be signed by another CA that you control.
        certificate_chain(bytes, optional): A PEM-encoded file that contains all of your certificates, other than the certificate you're importing, chaining up to your root CA. Your ACM Private CA-hosted or on-premises root certificate is the last in the chain, and each certificate in the chain signs the one preceding.  This parameter must be supplied when you import a subordinate CA. When you import a root CA, there is no chain. Defaults to None.
    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.acm_pca.certificate.authority.certificate.import(ctx, certificate_authority_arn=value, certificate=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.acm_pca.certificate.authority.certificate.import certificate_authority_arn=value, certificate=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="acm-pca",
        operation="import_certificate_authority_certificate",
        op_kwargs={
            "CertificateAuthorityArn": certificate_authority_arn,
            "Certificate": certificate,
            "CertificateChain": certificate_chain,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


__func_alias__ = {"list_": "list"}


async def create(
    hub,
    ctx,
    directory_arn: str,
    ordered_indexed_attribute_list: List,
    is_unique: bool,
    parent_reference: Dict = None,
    link_name: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Creates an index object. See Indexing and search for more information.

    Args:
        directory_arn(str): The ARN of the directory where the index should be created.
        ordered_indexed_attribute_list(List): Specifies the attributes that should be indexed on. Currently only a single attribute is supported.
        is_unique(bool): Indicates whether the attribute that is being indexed has unique values or not.
        parent_reference(Dict, optional): A reference to the parent object that contains the index object. Defaults to None.
        link_name(str, optional): The name of the link between the parent object and the index object. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.clouddirectory.index.create(
                ctx, directory_arn=value, ordered_indexed_attribute_list=value, is_unique=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.clouddirectory.index.create directory_arn=value, ordered_indexed_attribute_list=value, is_unique=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="clouddirectory",
        operation="create_index",
        op_kwargs={
            "DirectoryArn": directory_arn,
            "OrderedIndexedAttributeList": ordered_indexed_attribute_list,
            "IsUnique": is_unique,
            "ParentReference": parent_reference,
            "LinkName": link_name,
        },
    )


async def list_(
    hub,
    ctx,
    directory_arn: str,
    index_reference: Dict,
    ranges_on_indexed_values: List = None,
    max_results: int = None,
    next_token: str = None,
    consistency_level: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Lists objects attached to the specified index.

    Args:
        directory_arn(str): The ARN of the directory that the index exists in.
        ranges_on_indexed_values(List, optional): Specifies the ranges of indexed values that you want to query. Defaults to None.
        index_reference(Dict): The reference to the index to list.
        max_results(int, optional): The maximum number of objects in a single page to retrieve from the index during a request. For more information, see Amazon Cloud Directory Limits. Defaults to None.
        next_token(str, optional): The pagination token. Defaults to None.
        consistency_level(str, optional): The consistency level to execute the request at. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.clouddirectory.index.list(
                ctx, directory_arn=value, index_reference=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.clouddirectory.index.list directory_arn=value, index_reference=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="clouddirectory",
        operation="list_index",
        op_kwargs={
            "DirectoryArn": directory_arn,
            "RangesOnIndexedValues": ranges_on_indexed_values,
            "IndexReference": index_reference,
            "MaxResults": max_results,
            "NextToken": next_token,
            "ConsistencyLevel": consistency_level,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def create(hub, ctx, distribution_id: str, monitoring_subscription: Dict) -> Dict:
    r"""
    **Autogenerated function**

    Enables additional CloudWatch metrics for the specified CloudFront distribution. The additional metrics incur an additional cost. For more information, see Viewing additional CloudFront distribution metrics in the Amazon CloudFront Developer Guide.

    Args:
        distribution_id(str): The ID of the distribution that you are enabling metrics for.
        monitoring_subscription(Dict): A monitoring subscription. This structure contains information about whether additional CloudWatch metrics are enabled for a given CloudFront distribution.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.cloudfront.monitoring_subscription.create(
                ctx, distribution_id=value, monitoring_subscription=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.cloudfront.monitoring_subscription.create distribution_id=value, monitoring_subscription=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="cloudfront",
        operation="create_monitoring_subscription",
        op_kwargs={
            "DistributionId": distribution_id,
            "MonitoringSubscription": monitoring_subscription,
        },
    )


async def delete(hub, ctx, distribution_id: str) -> Dict:
    r"""
    **Autogenerated function**

    Disables additional CloudWatch metrics for the specified CloudFront distribution.

    Args:
        distribution_id(str): The ID of the distribution that you are disabling metrics for.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.cloudfront.monitoring_subscription.delete(
                ctx, distribution_id=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.cloudfront.monitoring_subscription.delete distribution_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="cloudfront",
        operation="delete_monitoring_subscription",
        op_kwargs={"DistributionId": distribution_id},
    )


async def get(hub, ctx, distribution_id: str) -> Dict:
    r"""
    **Autogenerated function**

    Gets information about whether additional CloudWatch metrics are enabled for the specified CloudFront distribution.

    Args:
        distribution_id(str): The ID of the distribution that you are getting metrics information for.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.cloudfront.monitoring_subscription.get(
                ctx, distribution_id=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.cloudfront.monitoring_subscription.get distribution_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="cloudfront",
        operation="get_monitoring_subscription",
        op_kwargs={"DistributionId": distribution_id},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def get_all(
    hub,
    ctx,
    query_string: str,
    index_name: str = None,
    aggregation_field: str = None,
    query_version: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Returns the count, average, sum, minimum, maximum, sum of squares, variance, and standard deviation for the specified aggregated field. If the aggregation field is of type String, only the count statistic is returned.

    Args:
        index_name(str, optional): The name of the index to search. The default value is AWS_Things. Defaults to None.
        query_string(str): The query used to search. You can specify "*" for the query string to get the count of all indexed things in your AWS account.
        aggregation_field(str, optional): The aggregation field name. Defaults to None.
        query_version(str, optional): The version of the query used to search. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.iot.statistic.get_all(ctx, query_string=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.iot.statistic.get_all query_string=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="iot",
        operation="get_statistics",
        op_kwargs={
            "indexName": index_name,
            "queryString": query_string,
            "aggregationField": aggregation_field,
            "queryVersion": query_version,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


__virtualname__ = "ip_address_type"


__func_alias__ = {"set_": "set"}


async def set_(
    hub, ctx, resource_type: str, resource_name: str, ip_address_type: str
) -> Dict:
    r"""
    **Autogenerated function**

    Sets the IP address type for an Amazon Lightsail resource. Use this action to enable dual-stack for a resource, which enables IPv4 and IPv6 for the specified resource. Alternately, you can use this action to disable dual-stack, and enable IPv4 only.

    Args:
        resource_type(str): The resource type. The possible values are Distribution, Instance, and LoadBalancer.  Distribution-related APIs are available only in the N. Virginia (us-east-1) AWS Region. Set your AWS Region configuration to us-east-1 to create, view, or edit distributions. .
        resource_name(str): The name of the resource for which to set the IP address type.
        ip_address_type(str): The IP address type to set for the specified resource. The possible values are ipv4 for IPv4 only, and dualstack for IPv4 and IPv6.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.lightsail.ip_address_type_.set(
                ctx, resource_type=value, resource_name=value, ip_address_type=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.lightsail.ip_address_type.set resource_type=value, resource_name=value, ip_address_type=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="lightsail",
        operation="set_ip_address_type",
        op_kwargs={
            "resourceType": resource_type,
            "resourceName": resource_name,
            "ipAddressType": ip_address_type,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def get(
    hub,
    ctx,
    launch_profile_id: str,
    launch_profile_protocol_versions: List,
    launch_purpose: str,
    platform: str,
    studio_id: str,
) -> Dict:
    r"""
    **Autogenerated function**

    Get a launch profile initialization.

    Args:
        launch_profile_id(str): The launch profile ID.
        launch_profile_protocol_versions(List): A collection of launch profile protocol versions.
        launch_purpose(str): The launch purpose.
        platform(str): The platform.
        studio_id(str): The studio ID.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.nimble.launch_profile.initialization.get(
                ctx,
                launch_profile_id=value,
                launch_profile_protocol_versions=value,
                launch_purpose=value,
                platform=value,
                studio_id=value,
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.nimble.launch_profile.initialization.get launch_profile_id=value, launch_profile_protocol_versions=value, launch_purpose=value, platform=value, studio_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="nimble",
        operation="get_launch_profile_initialization",
        op_kwargs={
            "launchProfileId": launch_profile_id,
            "launchProfileProtocolVersions": launch_profile_protocol_versions,
            "launchPurpose": launch_purpose,
            "platform": platform,
            "studioId": studio_id,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


__func_alias__ = {"list_": "list"}


async def list_(hub, ctx, max_results: int = None, next_token: str = None) -> Dict:
    r"""
    **Autogenerated function**

    Lists map resources in your AWS account.

    Args:
        max_results(int, optional): An optional limit for the number of resources returned in a single call.  Default value: 100 . Defaults to None.
        next_token(str, optional): The pagination token specifying which page of results to return in the response. If no token is provided, the default page is the first page. Default value: null . Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.location.maps.list(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.location.maps.list
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="location",
        operation="list_maps",
        op_kwargs={"MaxResults": max_results, "NextToken": next_token},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def execute(
    hub,
    ctx,
    command: str,
    interactive: bool,
    task: str,
    cluster: str = None,
    container: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Runs a command remotely on a container within a task.

    Args:
        cluster(str, optional): The Amazon Resource Name (ARN) or short name of the cluster the task is running in. If you do not specify a cluster, the default cluster is assumed. Defaults to None.
        container(str, optional): The name of the container to execute the command on. A container name only needs to be specified for tasks containing multiple containers. Defaults to None.
        command(str): The command to run on the container.
        interactive(bool): Use this flag to run your command in interactive mode.
        task(str): The Amazon Resource Name (ARN) or ID of the task the container is part of.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.ecs.command.execute(
                ctx, command=value, interactive=value, task=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.ecs.command.execute command=value, interactive=value, task=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="ecs",
        operation="execute_command",
        op_kwargs={
            "cluster": cluster,
            "container": container,
            "command": command,
            "interactive": interactive,
            "task": task,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def tag(hub, ctx, resource_arn: str, tags: Dict) -> None:
    r"""
    **Autogenerated function**

    Adds or overwrites only the specified tags for the specified Application Migration Service resource or resources. When you specify an existing tag key, the value is overwritten with the new value. Each resource can have a maximum of 50 tags. Each tag consists of a key and optional value.

    Args:
        resource_arn(str): Tag resource by ARN.
        tags(Dict): Tag resource by Tags.
    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.mgn.resource.tag(ctx, resource_arn=value, tags=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.mgn.resource.tag resource_arn=value, tags=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="mgn",
        operation="tag_resource",
        op_kwargs={"resourceArn": resource_arn, "tags": tags},
    )


async def untag(hub, ctx, resource_arn: str, tag_keys: List) -> None:
    r"""
    **Autogenerated function**

    Deletes the specified set of tags from the specified set of Application Migration Service resources.

    Args:
        resource_arn(str): Untag resource by ARN.
        tag_keys(List): Untag resource by Keys.
    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.mgn.resource.untag(ctx, resource_arn=value, tag_keys=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.mgn.resource.untag resource_arn=value, tag_keys=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="mgn",
        operation="untag_resource",
        op_kwargs={"resourceArn": resource_arn, "tagKeys": tag_keys},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def tag(hub, ctx, resource_arn: str, tags: List) -> Dict:
    r"""
    **Autogenerated function**

     Adds a user specifed key and value tag to a Data Store.

    Args:
        resource_arn(str):  The Amazon Resource Name(ARN)that gives Amazon HealthLake access to the Data Store which tags are being added to. .
        tags(List):  The user specified key and value pair tags being added to a Data Store. .

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.healthlake.resource.tag(ctx, resource_arn=value, tags=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.healthlake.resource.tag resource_arn=value, tags=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="healthlake",
        operation="tag_resource",
        op_kwargs={"ResourceARN": resource_arn, "Tags": tags},
    )


async def untag(hub, ctx, resource_arn: str, tag_keys: List) -> Dict:
    r"""
    **Autogenerated function**

     Removes tags from a Data Store.

    Args:
        resource_arn(str):  "The Amazon Resource Name(ARN) of the Data Store for which tags are being removed .
        tag_keys(List):  The keys for the tags to be removed from the Healthlake Data Store. .

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.healthlake.resource.untag(
                ctx, resource_arn=value, tag_keys=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.healthlake.resource.untag resource_arn=value, tag_keys=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="healthlake",
        operation="untag_resource",
        op_kwargs={"ResourceARN": resource_arn, "TagKeys": tag_keys},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def disable(hub, ctx) -> Dict:
    r"""
    **Autogenerated function**

    Disables using Service Catalog in SageMaker. Service Catalog is used to create SageMaker projects.


    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.sagemaker.sagemaker_servicecatalog_portfolio.init.disable(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.sagemaker.sagemaker_servicecatalog_portfolio.init.disable
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="sagemaker",
        operation="disable_sagemaker_servicecatalog_portfolio",
        op_kwargs={},
    )


async def enable(hub, ctx) -> Dict:
    r"""
    **Autogenerated function**

    Enables using Service Catalog in SageMaker. Service Catalog is used to create SageMaker projects.


    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.sagemaker.sagemaker_servicecatalog_portfolio.init.enable(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.sagemaker.sagemaker_servicecatalog_portfolio.init.enable
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="sagemaker",
        operation="enable_sagemaker_servicecatalog_portfolio",
        op_kwargs={},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def create(
    hub,
    ctx,
    detector_id: str,
    destination_type: str,
    destination_properties: Dict,
    client_token: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Creates a publishing destination to export findings to. The resource to export findings to must exist before you use this operation.

    Args:
        detector_id(str): The ID of the GuardDuty detector associated with the publishing destination.
        destination_type(str): The type of resource for the publishing destination. Currently only Amazon S3 buckets are supported.
        destination_properties(Dict): The properties of the publishing destination, including the ARNs for the destination and the KMS key used for encryption.
        client_token(str, optional): The idempotency token for the request. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.guardduty.publishing_destination.create(
                ctx, detector_id=value, destination_type=value, destination_properties=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.guardduty.publishing_destination.create detector_id=value, destination_type=value, destination_properties=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="guardduty",
        operation="create_publishing_destination",
        op_kwargs={
            "DetectorId": detector_id,
            "DestinationType": destination_type,
            "DestinationProperties": destination_properties,
            "ClientToken": client_token,
        },
    )


async def delete(hub, ctx, detector_id: str, destination_id: str) -> Dict:
    r"""
    **Autogenerated function**

    Deletes the publishing definition with the specified destinationId.

    Args:
        detector_id(str): The unique ID of the detector associated with the publishing destination to delete.
        destination_id(str): The ID of the publishing destination to delete.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.guardduty.publishing_destination.delete(
                ctx, detector_id=value, destination_id=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.guardduty.publishing_destination.delete detector_id=value, destination_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="guardduty",
        operation="delete_publishing_destination",
        op_kwargs={"DetectorId": detector_id, "DestinationId": destination_id},
    )


async def describe(hub, ctx, detector_id: str, destination_id: str) -> Dict:
    r"""
    **Autogenerated function**

    Returns information about the publishing destination specified by the provided destinationId.

    Args:
        detector_id(str): The unique ID of the detector associated with the publishing destination to retrieve.
        destination_id(str): The ID of the publishing destination to retrieve.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.guardduty.publishing_destination.describe(
                ctx, detector_id=value, destination_id=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.guardduty.publishing_destination.describe detector_id=value, destination_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="guardduty",
        operation="describe_publishing_destination",
        op_kwargs={"DetectorId": detector_id, "DestinationId": destination_id},
    )


async def list_all(
    hub, ctx, detector_id: str, max_results: int = None, next_token: str = None
) -> Dict:
    r"""
    **Autogenerated function**

    Returns a list of publishing destinations associated with the specified dectectorId.

    Args:
        detector_id(str): The ID of the detector to retrieve publishing destinations for.
        max_results(int, optional): The maximum number of results to return in the response. Defaults to None.
        next_token(str, optional): A token to use for paginating results that are returned in the response. Set the value of this parameter to null for the first request to a list action. For subsequent calls, use the NextToken value returned from the previous request to continue listing results after the first page. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.guardduty.publishing_destination.list_all(
                ctx, detector_id=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.guardduty.publishing_destination.list_all detector_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="guardduty",
        operation="list_publishing_destinations",
        op_kwargs={
            "DetectorId": detector_id,
            "MaxResults": max_results,
            "NextToken": next_token,
        },
    )


async def update(
    hub, ctx, detector_id: str, destination_id: str, destination_properties: Dict = None
) -> Dict:
    r"""
    **Autogenerated function**

    Updates information about the publishing destination specified by the destinationId.

    Args:
        detector_id(str): The ID of the detector associated with the publishing destinations to update.
        destination_id(str): The ID of the publishing destination to update.
        destination_properties(Dict, optional): A DestinationProperties object that includes the DestinationArn and KmsKeyArn of the publishing destination. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.guardduty.publishing_destination.update(
                ctx, detector_id=value, destination_id=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.guardduty.publishing_destination.update detector_id=value, destination_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="guardduty",
        operation="update_publishing_destination",
        op_kwargs={
            "DetectorId": detector_id,
            "DestinationId": destination_id,
            "DestinationProperties": destination_properties,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def send(
    hub,
    ctx,
    source: str,
    template: str,
    destinations: List,
    source_arn: str = None,
    reply_to_addresses: List = None,
    return_path: str = None,
    return_path_arn: str = None,
    configuration_set_name: str = None,
    default_tags: List = None,
    template_arn: str = None,
    default_template_data: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Composes an email message to multiple destinations. The message body is created using an email template. In order to send email using the SendBulkTemplatedEmail operation, your call to the API must meet the following requirements:   The call must refer to an existing email template. You can create email templates using the CreateTemplate operation.   The message must be sent from a verified email address or domain.   If your account is still in the Amazon SES sandbox, you may only send to verified addresses or domains, or to email addresses associated with the Amazon SES Mailbox Simulator. For more information, see Verifying Email Addresses and Domains in the Amazon SES Developer Guide.    The maximum message size is 10 MB.   Each Destination parameter must include at least one recipient email address. The recipient address can be a To: address, a CC: address, or a BCC: address. If a recipient email address is invalid (that is, it is not in the format UserName@[SubDomain.]Domain.TopLevelDomain), the entire message will be rejected, even if the message contains other recipients that are valid.   The message may not include more than 50 recipients, across the To:, CC: and BCC: fields. If you need to send an email message to a larger audience, you can divide your recipient list into groups of 50 or fewer, and then call the SendBulkTemplatedEmail operation several times to send the message to each group.   The number of destinations you can contact in a single call to the API may be limited by your account's maximum sending rate.

    Args:
        source(str): The email address that is sending the email. This email address must be either individually verified with Amazon SES, or from a domain that has been verified with Amazon SES. For information about verifying identities, see the Amazon SES Developer Guide. If you are sending on behalf of another user and have been permitted to do so by a sending authorization policy, then you must also specify the SourceArn parameter. For more information about sending authorization, see the Amazon SES Developer Guide.  Amazon SES does not support the SMTPUTF8 extension, as described in RFC6531. For this reason, the local part of a source email address (the part of the email address that precedes the @ sign) may only contain 7-bit ASCII characters. If the domain part of an address (the part after the @ sign) contains non-ASCII characters, they must be encoded using Punycode, as described in RFC3492. The sender name (also known as the friendly name) may contain non-ASCII characters. These characters must be encoded using MIME encoded-word syntax, as described in RFC 2047. MIME encoded-word syntax uses the following form: =?charset?encoding?encoded-text?=. .
        source_arn(str, optional): This parameter is used only for sending authorization. It is the ARN of the identity that is associated with the sending authorization policy that permits you to send for the email address specified in the Source parameter. For example, if the owner of example.com (which has ARN arn:aws:ses:us-east-1:123456789012:identity/example.com) attaches a policy to it that authorizes you to send from user@example.com, then you would specify the SourceArn to be arn:aws:ses:us-east-1:123456789012:identity/example.com, and the Source to be user@example.com. For more information about sending authorization, see the Amazon SES Developer Guide. Defaults to None.
        reply_to_addresses(List, optional): The reply-to email address(es) for the message. If the recipient replies to the message, each reply-to address will receive the reply. Defaults to None.
        return_path(str, optional): The email address that bounces and complaints will be forwarded to when feedback forwarding is enabled. If the message cannot be delivered to the recipient, then an error message will be returned from the recipient's ISP; this message will then be forwarded to the email address specified by the ReturnPath parameter. The ReturnPath parameter is never overwritten. This email address must be either individually verified with Amazon SES, or from a domain that has been verified with Amazon SES. . Defaults to None.
        return_path_arn(str, optional): This parameter is used only for sending authorization. It is the ARN of the identity that is associated with the sending authorization policy that permits you to use the email address specified in the ReturnPath parameter. For example, if the owner of example.com (which has ARN arn:aws:ses:us-east-1:123456789012:identity/example.com) attaches a policy to it that authorizes you to use feedback@example.com, then you would specify the ReturnPathArn to be arn:aws:ses:us-east-1:123456789012:identity/example.com, and the ReturnPath to be feedback@example.com. For more information about sending authorization, see the Amazon SES Developer Guide. Defaults to None.
        configuration_set_name(str, optional): The name of the configuration set to use when you send an email using SendBulkTemplatedEmail. Defaults to None.
        default_tags(List, optional): A list of tags, in the form of name/value pairs, to apply to an email that you send to a destination using SendBulkTemplatedEmail. Defaults to None.
        template(str): The template to use when sending this email.
        template_arn(str, optional): The ARN of the template to use when sending this email. Defaults to None.
        default_template_data(str, optional): A list of replacement values to apply to the template when replacement data is not specified in a Destination object. These values act as a default or fallback option when no other data is available. The template data is a JSON object, typically consisting of key-value pairs in which the keys correspond to replacement tags in the email template. Defaults to None.
        destinations(List): One or more Destination objects. All of the recipients in a Destination will receive the same version of the email. You can specify up to 50 Destination objects within a Destinations array.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.ses.bulk_templated_email.send(
                ctx, source=value, template=value, destinations=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.ses.bulk_templated_email.send source=value, template=value, destinations=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="ses",
        operation="send_bulk_templated_email",
        op_kwargs={
            "Source": source,
            "SourceArn": source_arn,
            "ReplyToAddresses": reply_to_addresses,
            "ReturnPath": return_path,
            "ReturnPathArn": return_path_arn,
            "ConfigurationSetName": configuration_set_name,
            "DefaultTags": default_tags,
            "Template": template,
            "TemplateArn": template_arn,
            "DefaultTemplateData": default_template_data,
            "Destinations": destinations,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def create(
    hub,
    ctx,
    auto_scaling_configuration_name: str,
    max_concurrency: int = None,
    min_size: int = None,
    max_size: int = None,
    tags: List = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Create an AWS App Runner automatic scaling configuration resource. App Runner requires this resource when you create App Runner services that require non-default auto scaling settings. You can share an auto scaling configuration across multiple services. Create multiple revisions of a configuration by using the same AutoScalingConfigurationName and different AutoScalingConfigurationRevision values. When you create a service, you can set it to use the latest active revision of an auto scaling configuration or a specific revision. Configure a higher MinSize to increase the spread of your App Runner service over more Availability Zones in the AWS Region. The tradeoff is a higher minimal cost. Configure a lower MaxSize to control your cost. The tradeoff is lower responsiveness during peak demand.

    Args:
        auto_scaling_configuration_name(str): A name for the auto scaling configuration. When you use it for the first time in an AWS Region, App Runner creates revision number 1 of this name. When you use the same name in subsequent calls, App Runner creates incremental revisions of the configuration.
        max_concurrency(int, optional): The maximum number of concurrent requests that you want an instance to process. If the number of concurrent requests exceeds this limit, App Runner scales up your service. Default: 100 . Defaults to None.
        min_size(int, optional): The minimum number of instances that App Runner provisions for your service. The service always has at least MinSize provisioned instances. Some of them actively serve traffic. The rest of them (provisioned and inactive instances) are a cost-effective compute capacity reserve and are ready to be quickly activated. You pay for memory usage of all the provisioned instances. You pay for CPU usage of only the active subset. App Runner temporarily doubles the number of provisioned instances during deployments, to maintain the same capacity for both old and new code. Default: 1 . Defaults to None.
        max_size(int, optional): The maximum number of instances that your service scales up to. At most MaxSize instances actively serve traffic for your service. Default: 25 . Defaults to None.
        tags(List, optional): A list of metadata items that you can associate with your auto scaling configuration resource. A tag is a key-value pair. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.apprunner.auto_scaling_configuration.create(
                ctx, auto_scaling_configuration_name=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.apprunner.auto_scaling_configuration.create auto_scaling_configuration_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="apprunner",
        operation="create_auto_scaling_configuration",
        op_kwargs={
            "AutoScalingConfigurationName": auto_scaling_configuration_name,
            "MaxConcurrency": max_concurrency,
            "MinSize": min_size,
            "MaxSize": max_size,
            "Tags": tags,
        },
    )


async def delete(hub, ctx, auto_scaling_configuration_arn: str) -> Dict:
    r"""
    **Autogenerated function**

    Delete an AWS App Runner automatic scaling configuration resource. You can delete a specific revision or the latest active revision. You can't delete a configuration that's used by one or more App Runner services.

    Args:
        auto_scaling_configuration_arn(str): The Amazon Resource Name (ARN) of the App Runner auto scaling configuration that you want to delete. The ARN can be a full auto scaling configuration ARN, or a partial ARN ending with either .../name  or .../name/revision . If a revision isn't specified, the latest active revision is deleted.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.apprunner.auto_scaling_configuration.delete(
                ctx, auto_scaling_configuration_arn=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.apprunner.auto_scaling_configuration.delete auto_scaling_configuration_arn=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="apprunner",
        operation="delete_auto_scaling_configuration",
        op_kwargs={"AutoScalingConfigurationArn": auto_scaling_configuration_arn},
    )


async def describe(hub, ctx, auto_scaling_configuration_arn: str) -> Dict:
    r"""
    **Autogenerated function**

    Return a full description of an AWS App Runner automatic scaling configuration resource.

    Args:
        auto_scaling_configuration_arn(str): The Amazon Resource Name (ARN) of the App Runner auto scaling configuration that you want a description for. The ARN can be a full auto scaling configuration ARN, or a partial ARN ending with either .../name  or .../name/revision . If a revision isn't specified, the latest active revision is described.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.apprunner.auto_scaling_configuration.describe(
                ctx, auto_scaling_configuration_arn=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.apprunner.auto_scaling_configuration.describe auto_scaling_configuration_arn=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="apprunner",
        operation="describe_auto_scaling_configuration",
        op_kwargs={"AutoScalingConfigurationArn": auto_scaling_configuration_arn},
    )


async def list_all(
    hub,
    ctx,
    auto_scaling_configuration_name: str = None,
    latest_only: bool = None,
    max_results: int = None,
    next_token: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Returns a list of AWS App Runner automatic scaling configurations in your AWS account. You can query the revisions for a specific configuration name or the revisions for all configurations in your account. You can optionally query only the latest revision of each requested name.

    Args:
        auto_scaling_configuration_name(str, optional): The name of the App Runner auto scaling configuration that you want to list. If specified, App Runner lists revisions that share this name. If not specified, App Runner returns revisions of all configurations. Defaults to None.
        latest_only(bool, optional): Set to true to list only the latest revision for each requested configuration name. Keep as false to list all revisions for each requested configuration name. Default: false . Defaults to None.
        max_results(int, optional): The maximum number of results to include in each response (result page). It's used for a paginated request. If you don't specify MaxResults, the request retrieves all available results in a single response. Defaults to None.
        next_token(str, optional): A token from a previous result page. It's used for a paginated request. The request retrieves the next result page. All other parameter values must be identical to the ones that are specified in the initial request. If you don't specify NextToken, the request retrieves the first result page. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.apprunner.auto_scaling_configuration.list_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.apprunner.auto_scaling_configuration.list_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="apprunner",
        operation="list_auto_scaling_configurations",
        op_kwargs={
            "AutoScalingConfigurationName": auto_scaling_configuration_name,
            "LatestOnly": latest_only,
            "MaxResults": max_results,
            "NextToken": next_token,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def get_all(hub, ctx, predictor_arn: str) -> Dict:
    r"""
    **Autogenerated function**

    Provides metrics on the accuracy of the models that were trained by the CreatePredictor operation. Use metrics to see how well the model performed and to decide whether to use the predictor to generate a forecast. For more information, see Predictor Metrics. This operation generates metrics for each backtest window that was evaluated. The number of backtest windows (NumberOfBacktestWindows) is specified using the EvaluationParameters object, which is optionally included in the CreatePredictor request. If NumberOfBacktestWindows isn't specified, the number defaults to one. The parameters of the filling method determine which items contribute to the metrics. If you want all items to contribute, specify zero. If you want only those items that have complete data in the range being evaluated to contribute, specify nan. For more information, see FeaturizationMethod.  Before you can get accuracy metrics, the Status of the predictor must be ACTIVE, signifying that training has completed. To get the status, use the DescribePredictor operation.

    Args:
        predictor_arn(str): The Amazon Resource Name (ARN) of the predictor to get metrics for.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.forecast.accuracy_metric.get_all(ctx, predictor_arn=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.forecast.accuracy_metric.get_all predictor_arn=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="forecast",
        operation="get_accuracy_metrics",
        op_kwargs={"PredictorArn": predictor_arn},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def create(
    hub,
    ctx,
    recognizer_name: str,
    data_access_role_arn: str,
    input_data_config: Dict,
    language_code: str,
    tags: List = None,
    client_request_token: str = None,
    volume_kms_key_id: str = None,
    vpc_config: Dict = None,
    model_kms_key_id: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Creates an entity recognizer using submitted files. After your CreateEntityRecognizer request is submitted, you can check job status using the API.

    Args:
        recognizer_name(str): The name given to the newly created recognizer. Recognizer names can be a maximum of 256 characters. Alphanumeric characters, hyphens (-) and underscores (_) are allowed. The name must be unique in the account/region.
        data_access_role_arn(str): The Amazon Resource Name (ARN) of the AWS Identity and Management (IAM) role that grants Amazon Comprehend read access to your input data.
        tags(List, optional): Tags to be associated with the entity recognizer being created. A tag is a key-value pair that adds as a metadata to a resource used by Amazon Comprehend. For example, a tag with "Sales" as the key might be added to a resource to indicate its use by the sales department. . Defaults to None.
        input_data_config(Dict): Specifies the format and location of the input data. The S3 bucket containing the input data must be located in the same region as the entity recognizer being created. .
        client_request_token(str, optional):  A unique identifier for the request. If you don't set the client request token, Amazon Comprehend generates one. Defaults to None.
        language_code(str):  You can specify any of the following languages supported by Amazon Comprehend: English ("en"), Spanish ("es"), French ("fr"), Italian ("it"), German ("de"), or Portuguese ("pt"). All documents must be in the same language.
        volume_kms_key_id(str, optional): ID for the AWS Key Management Service (KMS) key that Amazon Comprehend uses to encrypt data on the storage volume attached to the ML compute instance(s) that process the analysis job. The VolumeKmsKeyId can be either of the following formats:   KMS Key ID: "1234abcd-12ab-34cd-56ef-1234567890ab"    Amazon Resource Name (ARN) of a KMS Key: "arn:aws:kms:us-west-2:111122223333:key/1234abcd-12ab-34cd-56ef-1234567890ab"   . Defaults to None.
        vpc_config(Dict, optional): Configuration parameters for an optional private Virtual Private Cloud (VPC) containing the resources you are using for your custom entity recognizer. For more information, see Amazon VPC. . Defaults to None.
        model_kms_key_id(str, optional): ID for the AWS Key Management Service (KMS) key that Amazon Comprehend uses to encrypt trained custom models. The ModelKmsKeyId can be either of the following formats   KMS Key ID: "1234abcd-12ab-34cd-56ef-1234567890ab"    Amazon Resource Name (ARN) of a KMS Key: "arn:aws:kms:us-west-2:111122223333:key/1234abcd-12ab-34cd-56ef-1234567890ab"   . Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.comprehend.entity.recognizer.create(
                ctx,
                recognizer_name=value,
                data_access_role_arn=value,
                input_data_config=value,
                language_code=value,
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.comprehend.entity.recognizer.create recognizer_name=value, data_access_role_arn=value, input_data_config=value, language_code=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="comprehend",
        operation="create_entity_recognizer",
        op_kwargs={
            "RecognizerName": recognizer_name,
            "DataAccessRoleArn": data_access_role_arn,
            "Tags": tags,
            "InputDataConfig": input_data_config,
            "ClientRequestToken": client_request_token,
            "LanguageCode": language_code,
            "VolumeKmsKeyId": volume_kms_key_id,
            "VpcConfig": vpc_config,
            "ModelKmsKeyId": model_kms_key_id,
        },
    )


async def delete(hub, ctx, entity_recognizer_arn: str) -> Dict:
    r"""
    **Autogenerated function**

    Deletes an entity recognizer. Only those recognizers that are in terminated states (IN_ERROR, TRAINED) will be deleted. If an active inference job is using the model, a ResourceInUseException will be returned. This is an asynchronous action that puts the recognizer into a DELETING state, and it is then removed by a background job. Once removed, the recognizer disappears from your account and is no longer available for use.

    Args:
        entity_recognizer_arn(str): The Amazon Resource Name (ARN) that identifies the entity recognizer.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.comprehend.entity.recognizer.delete(
                ctx, entity_recognizer_arn=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.comprehend.entity.recognizer.delete entity_recognizer_arn=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="comprehend",
        operation="delete_entity_recognizer",
        op_kwargs={"EntityRecognizerArn": entity_recognizer_arn},
    )


async def describe(hub, ctx, entity_recognizer_arn: str) -> Dict:
    r"""
    **Autogenerated function**

    Provides details about an entity recognizer including status, S3 buckets containing training data, recognizer metadata, metrics, and so on.

    Args:
        entity_recognizer_arn(str): The Amazon Resource Name (ARN) that identifies the entity recognizer.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.comprehend.entity.recognizer.describe(
                ctx, entity_recognizer_arn=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.comprehend.entity.recognizer.describe entity_recognizer_arn=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="comprehend",
        operation="describe_entity_recognizer",
        op_kwargs={"EntityRecognizerArn": entity_recognizer_arn},
    )


async def list_all(
    hub, ctx, filter_: Dict = None, next_token: str = None, max_results: int = None
) -> Dict:
    r"""
    **Autogenerated function**

    Gets a list of the properties of all entity recognizers that you created, including recognizers currently in training. Allows you to filter the list of recognizers based on criteria such as status and submission time. This call returns up to 500 entity recognizers in the list, with a default number of 100 recognizers in the list. The results of this list are not in any particular order. Please get the list and sort locally if needed.

    Args:
        filter_(Dict, optional): Filters the list of entities returned. You can filter on Status, SubmitTimeBefore, or SubmitTimeAfter. You can only set one filter at a time. Defaults to None.
        next_token(str, optional): Identifies the next page of results to return. Defaults to None.
        max_results(int, optional):  The maximum number of results to return on each page. The default is 100. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.comprehend.entity.recognizer.list_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.comprehend.entity.recognizer.list_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="comprehend",
        operation="list_entity_recognizers",
        op_kwargs={
            "Filter": filter_,
            "NextToken": next_token,
            "MaxResults": max_results,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def associate(
    hub, ctx, s3_resources: List, member_account_id: str = None
) -> Dict:
    r"""
    **Autogenerated function**

    Associates specified S3 resources with Amazon Macie Classic for monitoring and data classification. If memberAccountId isn't specified, the action associates specified S3 resources with Macie Classic for the current Macie Classic administrator account. If memberAccountId is specified, the action associates specified S3 resources with Macie Classic for the specified member account.

    Args:
        member_account_id(str, optional): The ID of the Amazon Macie Classic member account whose resources you want to associate with Macie Classic. . Defaults to None.
        s3_resources(List): The S3 resources that you want to associate with Amazon Macie Classic for monitoring and data classification. .

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.macie.s3_resource.associate(ctx, s3_resources=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.macie.s3_resource.associate s3_resources=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="macie",
        operation="associate_s3_resources",
        op_kwargs={"memberAccountId": member_account_id, "s3Resources": s3_resources},
    )


async def disassociate(
    hub, ctx, associated_s3_resources: List, member_account_id: str = None
) -> Dict:
    r"""
    **Autogenerated function**

    Removes specified S3 resources from being monitored by Amazon Macie Classic. If memberAccountId isn't specified, the action removes specified S3 resources from Macie Classic for the current Macie Classic administrator account. If memberAccountId is specified, the action removes specified S3 resources from Macie Classic for the specified member account.

    Args:
        member_account_id(str, optional): The ID of the Amazon Macie Classic member account whose resources you want to remove from being monitored by Macie Classic. . Defaults to None.
        associated_s3_resources(List): The S3 resources (buckets or prefixes) that you want to remove from being monitored and classified by Amazon Macie Classic. .

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.macie.s3_resource.disassociate(
                ctx, associated_s3_resources=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.macie.s3_resource.disassociate associated_s3_resources=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="macie",
        operation="disassociate_s3_resources",
        op_kwargs={
            "memberAccountId": member_account_id,
            "associatedS3Resources": associated_s3_resources,
        },
    )


async def list_all(
    hub,
    ctx,
    member_account_id: str = None,
    next_token: str = None,
    max_results: int = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Lists all the S3 resources associated with Amazon Macie Classic. If memberAccountId isn't specified, the action lists the S3 resources associated with Macie Classic for the current Macie Classic administrator account. If memberAccountId is specified, the action lists the S3 resources associated with Macie Classic for the specified member account.

    Args:
        member_account_id(str, optional): The Amazon Macie Classic member account ID whose associated S3 resources you want to list. . Defaults to None.
        next_token(str, optional): Use this parameter when paginating results. Set its value to null on your first call to the ListS3Resources action. Subsequent calls to the action fill nextToken in the request with the value of nextToken from the previous response to continue listing data. . Defaults to None.
        max_results(int, optional): Use this parameter to indicate the maximum number of items that you want in the response. The default value is 250. . Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.macie.s3_resource.list_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.macie.s3_resource.list_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="macie",
        operation="list_s3_resources",
        op_kwargs={
            "memberAccountId": member_account_id,
            "nextToken": next_token,
            "maxResults": max_results,
        },
    )


async def update_multiple(
    hub, ctx, s3_resources_update: List, member_account_id: str = None
) -> Dict:
    r"""
    **Autogenerated function**

    Updates the classification types for the specified S3 resources. If memberAccountId isn't specified, the action updates the classification types of the S3 resources associated with Amazon Macie Classic for the current Macie Classic administrator account. If memberAccountId is specified, the action updates the classification types of the S3 resources associated with Macie Classic for the specified member account.

    Args:
        member_account_id(str, optional): The AWS ID of the Amazon Macie Classic member account whose S3 resources' classification types you want to update. . Defaults to None.
        s3_resources_update(List): The S3 resources whose classification types you want to update.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.macie.s3_resource.update_multiple(
                ctx, s3_resources_update=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.macie.s3_resource.update_multiple s3_resources_update=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="macie",
        operation="update_s3_resources",
        op_kwargs={
            "memberAccountId": member_account_id,
            "s3ResourcesUpdate": s3_resources_update,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def tag(hub, ctx, resource_arn: str, tags: List) -> Dict:
    r"""
    **Autogenerated function**

     This is AWS WAF Classic documentation. For more information, see AWS WAF Classic in the developer guide.  For the latest version of AWS WAF, use the AWS WAFV2 API and see the AWS WAF Developer Guide. With the latest version, AWS WAF has a single set of endpoints for regional and global use.   Associates tags with the specified AWS resource. Tags are key:value pairs that you can use to categorize and manage your resources, for purposes like billing. For example, you might set the tag key to "customer" and the value to the customer name or ID. You can specify one or more tags to add to each AWS resource, up to 50 tags for a resource. Tagging is only available through the API, SDKs, and CLI. You can't manage or view tags through the AWS WAF Classic console. You can use this action to tag the AWS resources that you manage through AWS WAF Classic: web ACLs, rule groups, and rules.

    Args:
        resource_arn(str): .
        tags(List): .

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.waf.resource.tag(ctx, resource_arn=value, tags=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.waf.resource.tag resource_arn=value, tags=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="waf",
        operation="tag_resource",
        op_kwargs={"ResourceARN": resource_arn, "Tags": tags},
    )


async def untag(hub, ctx, resource_arn: str, tag_keys: List) -> Dict:
    r"""
    **Autogenerated function**

     This is AWS WAF Classic documentation. For more information, see AWS WAF Classic in the developer guide.  For the latest version of AWS WAF, use the AWS WAFV2 API and see the AWS WAF Developer Guide. With the latest version, AWS WAF has a single set of endpoints for regional and global use.

    Args:
        resource_arn(str): .
        tag_keys(List): .

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.waf.resource.untag(ctx, resource_arn=value, tag_keys=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.waf.resource.untag resource_arn=value, tag_keys=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="waf",
        operation="untag_resource",
        op_kwargs={"ResourceARN": resource_arn, "TagKeys": tag_keys},
    )
